<?php

/*
 * Plugin Name: Giveaways for woocommerce
 * Plugin URI:
 * Description: The plugin is designed to send personal notifications about
 *                  coupons to users in their personal accounts of WooCommerce stores.
 * Version: 1.0.0
 * Author: Sindykin Sergei
 * Author URI: https://sindyakinsergei.com/
 * License: GNU General Public License v3.0
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: giveaways-for-woocommerce
 * Domain Path: /languages
 * WC requires at least: 3.0
 * WC tested up to: 3.4.5
 *
 * @fs_premium_only /includes/admin/filter/, /includes/coupon/analytics/, /includes/ajax/analytics/, /includes/query/
 */
/**
 * Exit if accessed directly.
 */
// Create a helper function for easy SDK access.
function wdocnu_fs()
{
    global  $wdocnu_fs ;
    
    if ( !isset( $wdocnu_fs ) ) {
        // Include Freemius SDK.
        require_once dirname( __FILE__ ) . '/freemius/start.php';
        $wdocnu_fs = fs_dynamic_init( array(
            'id'             => '2586',
            'slug'           => 'giveaways-for-woocommerce',
            'type'           => 'plugin',
            'public_key'     => 'pk_46f8edab7994bdd9fb61540914625',
            'is_premium'     => false,
            'has_addons'     => false,
            'has_paid_plans' => true,
            'menu'           => array(
            'slug'    => 'dcp-freemius-sse',
            'support' => false,
        ),
            'is_live'        => true,
        ) );
    }
    
    return $wdocnu_fs;
}

// Init Freemius.
wdocnu_fs();
// Signal that SDK was initiated.
do_action( 'wdocnu_fs_loaded' );
/**
 * Check if WooCommerce is active.
 */
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    
    if ( version_compare( get_option( 'woocommerce_db_version' ), '3.0', '>=' ) ) {
        class DISPATCH_OF_COUPONS
        {
            /**
             * Plugin actions.
             */
            public function __construct()
            {
                add_action( 'init', array( $this, 'add_endpoints_rules' ) );
                add_action( 'init', array( $this, 'incl_class_coupon' ) );
                add_action( 'init', array( $this, 'do_session_start' ) );
                /**
                 * Hook into actions.
                 */
                if ( is_admin() ) {
                    add_action( 'admin_enqueue_scripts', array( $this, 'admin_downloads_js_css' ), 10 );
                }
                add_action( 'wp_enqueue_scripts', array( $this, 'user_downloads_js_css' ), 100 );
                add_action( 'plugins_loaded', array( $this, 'dispatch_of_coupons_init' ) );
            }
            
            /**
             * Register new endpoint to use inside My Account page.
             */
            public static function add_endpoints_rules()
            {
                add_rewrite_endpoint( 'sse-new-coupon', EP_ROOT | EP_PAGES );
            }
            
            public static function dcp_path()
            {
                return untrailingslashit( plugin_dir_path( __FILE__ ) );
            }
            
            /**
             * Connecting classes.
             */
            public static function incl_class_coupon()
            {
                include dirname( __FILE__ ) . '/includes/admin/class-dcp-tab-coupon-sse.php';
                include dirname( __FILE__ ) . '/includes/admin/class-dcp-list-coupons-sse.php';
                include dirname( __FILE__ ) . '/includes/admin/class-dcp-admin-panel-sse.php';
                include dirname( __FILE__ ) . '/includes/coupon/class-dcp-cp-ntc-sse.php';
                include dirname( __FILE__ ) . '/includes/coupon/class-dcp-cp-ntc-data-store-cpt-sse.php';
                include dirname( __FILE__ ) . '/includes/coupon/class-dcp-cp-ntc-save-sse.php';
                include dirname( __FILE__ ) . '/includes/coupon/class-dcp-cp-session-save-sse.php';
                include dirname( __FILE__ ) . '/includes/notice/class-dcp-html-code-notif-sse.php';
                include dirname( __FILE__ ) . '/includes/notice/class-dcp-hook-notice-sse.php';
                include dirname( __FILE__ ) . '/includes/ajax/class-dcp-ajax-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-shortcodes-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-hook-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-admin-notices-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-functions-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-setting-ksess-sse.php';
                include dirname( __FILE__ ) . '/includes/class-dcp-endpoints-sse.php';
            }
            
            /**
             * The function of loading scripts and styles.
             */
            public static function admin_downloads_js_css()
            {
                $screen = get_current_screen();
                $screen_id = ( $screen ? $screen->id : '' );
                $wc_screen_id = sanitize_title( __( 'WooCommerce', 'woocommerce' ) );
                self::admin_scripts_all();
                
                if ( in_array( $screen_id, array( 'shop_coupon' ) ) ) {
                    self::admin_scripts();
                    self::admin_style();
                }
                
                
                if ( $wc_screen_id . '_page_wc-settings' === $screen_id && isset( $_GET['tab'] ) && 'dispatch_coupons' == $_GET['tab'] ) {
                    self::admin_scripts();
                    self::admin_style();
                }
                
                if ( 'toplevel_page_dcp-freemius-sse' === $screen_id ) {
                    self::admin_style();
                }
            }
            
            /**
             * Enqueue styles.
             */
            private function admin_style()
            {
                wp_enqueue_style(
                    'sage/css',
                    plugins_url( 'dist/styles/mainAdmin.css', __FILE__ ),
                    array( 'dashicons' ),
                    null
                );
            }
            
            /**
             * Connection of scripts for the admin panel.
             */
            private function admin_scripts()
            {
                wp_register_script(
                    'sse-moment',
                    plugins_url( 'dist/scripts/moment-with-locales.min.js', __FILE__ ),
                    array(
                    'jquery',
                    'woocommerce_admin',
                    'underscore',
                    'backbone'
                ),
                    null,
                    true
                );
                wp_enqueue_script( 'sse-moment' );
                wp_register_script(
                    'sse-datetimepicker',
                    plugins_url( 'dist/scripts/jquery.datetimepicker.min.js', __FILE__ ),
                    array(
                    'jquery',
                    'woocommerce_admin',
                    'underscore',
                    'backbone',
                    'sse-moment'
                ),
                    null,
                    true
                );
                wp_enqueue_script( 'sse-datetimepicker' );
                wp_register_script(
                    'sse-main',
                    plugins_url( 'assets/scripts/main.js', __FILE__ ),
                    array(
                    'jquery',
                    'woocommerce_admin',
                    'underscore',
                    'backbone',
                    'sse-moment',
                    'sse-datetimepicker'
                ),
                    null,
                    true
                );
                wp_enqueue_script( 'sse-main' );
            }
            
            /**
             * Connection of scripts for messages to the administrator.
             */
            private function admin_scripts_all()
            {
                wp_register_script(
                    'sse-mainAll',
                    plugins_url( 'assets/scripts/mainAll.js', __FILE__ ),
                    array(
                    'jquery',
                    'woocommerce_admin',
                    'underscore',
                    'backbone'
                ),
                    null,
                    true
                );
                wp_enqueue_script( 'sse-mainAll' );
                //Add styles.
                wp_enqueue_style(
                    'sage/css_1',
                    plugins_url( 'assets/styles/mainAdmin_all.css', __FILE__ ),
                    array( 'dashicons' ),
                    null
                );
                wp_localize_script( 'sse-mainAll', 'sse_disp_coupon_data', array(
                    'nonce' => wp_create_nonce( 'myajax-nonce' ),
                ) );
            }
            
            /**
             * Connect scripts and styles to the notification page.
             */
            public static function user_downloads_js_css()
            {
                
                if ( is_page( 'my-account' ) ) {
                    wp_register_script(
                        'sse-main-user',
                        plugins_url( 'assets/scripts/main_user.js', __FILE__ ),
                        array( 'jquery' ),
                        null,
                        true
                    );
                    wp_enqueue_script( 'sse-main-user' );
                    wp_localize_script( 'sse-main-user', 'sse_notices_coupon_data', array(
                        'url'   => admin_url( 'admin-ajax.php' ),
                        'nonce' => wp_create_nonce( 'myajax_nonce_user' ),
                    ) );
                }
            
            }
            
            /**
             * Make plagin available for translation.
             */
            public static function dispatch_of_coupons_init()
            {
                load_plugin_textdomain( 'wc-dispatch-of-coupons-notices-user', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
            }
            
            /**
             * Session start.
             */
            public static function do_session_start()
            {
                if ( !session_id() ) {
                    session_start();
                }
            }
        
        }
        new DISPATCH_OF_COUPONS();
        /**
         * Activation hooks.
         */
        register_activation_hook( __FILE__, 'dispatch_coupons_activate' );
        function dispatch_coupons_activate()
        {
            DISPATCH_OF_COUPONS::add_endpoints_rules();
            flush_rewrite_rules();
        }
        
        /**
         * Deactivation hooks.
         */
        register_deactivation_hook( __FILE__, 'dispatch_coupons_deactivate' );
        function dispatch_coupons_deactivate()
        {
            flush_rewrite_rules();
        }
    
    }

}