<?php

/**
 * The plug-in configuration panel.
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}
if ( !class_exists( 'WC_Settings_Dispatch_Coupons', false ) ) {
    /**
     * WC_Settings_Dispatch_Coupons.
     */
    class WC_Settings_Dispatch_Coupons extends WC_Settings_Page
    {
        /**
         * Constructor.
         */
        public function __construct()
        {
            $this->id = 'dispatch_coupons';
            $this->label = __( 'Giveaways WC', 'giveaways-for-woocommerce' );
            add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_page' ), 20 );
            add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );
            add_action( 'woocommerce_settings_' . $this->id, array( $this, 'output' ) );
            add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
        }
        
        /**
         * Get sections.
         *
         * @return array
         *
         */
        public function get_sections()
        {
            $sections = array(
                ''        => __( 'Administrator', 'giveaways-for-woocommerce' ),
                'notices' => __( 'User', 'giveaways-for-woocommerce' ),
            );
            return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
        }
        
        /**
         * Get settings array.
         *
         * @param string $current_section
         * @return array
         */
        public function get_settings( $current_section = '' )
        {
            global  $hide_save_button ;
            $settings = array();
            if ( '' === $current_section ) {
                if ( wdocnu_fs()->is_free_plan() ) {
                    $settings = apply_filters( 'woocommerce_dispatch_coupons_calendar_settings', array(
                        array(
                            'title' => __( 'Calendar settings', 'giveaways-for-woocommerce' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'sse_calendar_options',
                        ),
                        array(
                            'title'    => __( 'Calendar language', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'The language of the calendar does not depend on the settings of the site.', 'giveaways-for-woocommerce' ),
                            'id'       => 'woocommerce_localization_calendar',
                            'default'  => 'all',
                            'type'     => 'select',
                            'class'    => 'wc-enhanced-select',
                            'css'      => 'min-width: 350px;',
                            'desc_tip' => true,
                            'options'  => array(
                            'en' => __( 'English', 'giveaways-for-woocommerce' ),
                            'ru' => __( 'Russian', 'giveaways-for-woocommerce' ),
                        ),
                        ),
                        array(
                            'title'    => __( 'Date and time format', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Setting the date and time in the format moment.js.', 'giveaways-for-woocommerce' ),
                            'id'       => 'woocommerce_date_format_calendar',
                            'default'  => 'all',
                            'type'     => 'select',
                            'class'    => 'wc-enhanced-select',
                            'css'      => 'min-width: 350px;',
                            'desc_tip' => true,
                            'options'  => array(
                            'MM DD YY HH:mm'                => 'MM DD YY HH:mm',
                            'MM.DD.YY HH:mm'                => 'MM.DD.YY HH:mm',
                            'MM-DD-YY HH:mm'                => 'MM-DD-YY HH:mm',
                            'MM/DD/YY HH:mm'                => 'MM/DD/YY HH:mm',
                            'MM DD YYYY HH:mm'              => 'MM DD YYYY HH:mm',
                            'MM.DD.YYYY HH:mm'              => 'MM.DD.YYYY HH:mm',
                            'MM-DD-YYYY HH:mm'              => 'MM-DD-YYYY HH:mm',
                            'MM/DD/YYYY HH:mm'              => 'MM/DD/YYYY HH:mm',
                            'MMM DD YY HH:mm'               => 'MMM DD YY HH:mm',
                            'MMM.DD.YY HH:mm'               => 'MMM.DD.YY HH:mm',
                            'MMM-DD-YY HH:mm'               => 'MMM-DD-YY HH:mm',
                            'MMM/DD/YY HH:mm'               => 'MMM/DD/YY HH:mm',
                            'MMM DD YYYY HH:mm'             => 'MMM DD YYYY HH:mm',
                            'MMM.DD.YYYY HH:mm'             => 'MMM.DD.YYYY HH:mm',
                            'MMM-DD-YYYY HH:mm'             => 'MMM-DD-YYYY HH:mm',
                            'MMM/DD/YYYY HH:mm'             => 'MMM/DD/YYYY HH:mm',
                            'MMMM DD YYYY HH:mm'            => 'MMMM DD YYYY HH:mm',
                            'MMMM.DD.YYYY HH:mm'            => 'MMMM.DD.YYYY HH:mm',
                            'MMMM/DD/YYYY HH:mm'            => 'MMMM/DD/YYYY HH:mm',
                            'MM DD YYYY HH:mm:ss'           => 'MM DD YYYY HH:mm:ss',
                            'MM.DD.YYYY HH:mm:ss'           => 'MM.DD.YYYY HH:mm:ss',
                            'MM-DD-YYYY HH:mm:ss'           => 'MM-DD-YYYY HH:mm:ss',
                            'MM/DD/YYYY HH:mm:ss'           => 'MM/DD/YYYY HH:mm:ss',
                            'MMM DD YYYY HH:mm:ss'          => 'MMM DD YYYY HH:mm:ss',
                            'MMM.DD.YYYY HH:mm:ss'          => 'MMM.DD.YYYY HH:mm:ss',
                            'MMM-DD-YYYY HH:mm:ss'          => 'MMM-DD-YYYY HH:mm:ss',
                            'MMM/DD/YYYY HH:mm:ss'          => 'MMM/DD/YYYY HH:mm:ss',
                            'MMMM DD YYYY HH:mm:ss'         => 'MMMM DD YYYY HH:mm:ss',
                            'MMMM.DD.YYYY HH:mm:ss'         => 'MMMM.DD.YYYY HH:mm:ss',
                            'MMMM-DD-YYYY HH:mm:ss'         => 'MMMM-DD-YYYY HH:mm:ss',
                            'MMMM/DD/YYYY HH:mm:ss'         => 'MMMM/DD/YYYY HH:mm:ss',
                            'YY MM DD HH:mm'                => 'YY MM DD HH:mm',
                            'YY.MM.DD HH:mm'                => 'YY.MM.DD HH:mm',
                            'YY-MM-DD HH:mm'                => 'YY-MM-DD HH:mm',
                            'YY/MM/DD HH:mm'                => 'YY/MM/DD HH:mm',
                            'YYYY MM DD HH:mm'              => 'YYYY MM DD HH:mm',
                            'YYYY.MM.DD HH:mm'              => 'YYYY.MM.DD HH:mm',
                            'YYYY-MM-DD HH:mm'              => 'YYYY-MM-DD HH:mm',
                            'YYYY/MM/DD HH:mm'              => 'YYYY/MM/DD HH:mm',
                            'YY MMM DD HH:mm'               => 'YY MMM DD HH:mm',
                            'YY.MMM.DD HH:mm'               => 'YY.MMM.DD HH:mm',
                            'YY-MMM-DD HH:mm'               => 'YY-MMM-DD HH:mm',
                            'YY/MMM/DD HH:mm'               => 'YY/MMM/DD HH:mm',
                            'YYYY MMM DD HH:mm'             => 'YYYY MMM DD HH:mm',
                            'YYYY.MMM.DD HH:mm'             => 'YYYY.MMM.DD HH:mm',
                            'YYYY-MMM-DD HH:mm'             => 'YYYY-MMM-DD HH:mm',
                            'YYYY/MMM/DD HH:mm'             => 'YYYY/MMM/DD HH:mm',
                            'YYYY MMMM DD HH:mm'            => 'YYYY MMMM DD HH:mm',
                            'YYYY/MMMM/DD HH:mm'            => 'YYYY/MMMM/DD HH:mm',
                            'YYYY MM DD HH:mm:ss'           => 'YYYY MM DD HH:mm:ss',
                            'YYYY.MM.DD HH:mm:ss'           => 'YYYY.MM.DD HH:mm:ss',
                            'YYYY-MM-DD HH:mm:ss'           => 'YYYY-MM-DD HH:mm:ss',
                            'YYYY/MM/DD HH:mm:ss'           => 'YYYY/MM/DD HH:mm:ss',
                            'YYYY MMM DD HH:mm:ss'          => 'YYYY MMM DD HH:mm:ss',
                            'YYYY.MMM.DD HH:mm:ss'          => 'YYYY.MMM.DD HH:mm:ss',
                            'YYYY-MMM-DD HH:mm:ss'          => 'YYYY-MMM-DD HH:mm:ss',
                            'YYYY/MMM/DD HH:mm:ss'          => 'YYYY/MMM/DD HH:mm:ss',
                            'YYYY MMMM DD HH:mm:ss'         => 'YYYY MMMM DD HH:mm:ss',
                            'YYYY-MMMM-DD HH:mm:ss'         => 'YYYY-MMMM-DD HH:mm:ss',
                            'YYYY/MMMM/DD HH:mm:ss'         => 'YYYY/MMMM/DD HH:mm:ss',
                            'YYYY MM DD hh:mm:ss Z'         => 'YYYY MM DD hh:mm:ss Z',
                            'YYYY.MM.DD hh:mm:ss Z'         => 'YYYY.MM.DD hh:mm:ss Z',
                            'YYYY/MM/DD hh:mm:ss Z'         => 'YYYY/MM/DD hh:mm:ss Z',
                            'YYYY-MM-DD hh:mm:ss Z'         => 'YYYY-MM-DD hh:mm:ss Z',
                            'YYYY MM DD hh:mm:ss ZZ'        => 'YYYY MM DD hh:mm:ss ZZ',
                            'YYYY.MM.DD hh:mm:ss ZZ'        => 'YYYY.MM.DD hh:mm:ss ZZ',
                            'YYYY/MM/DD hh:mm:ss ZZ'        => 'YYYY/MM/DD hh:mm:ss ZZ',
                            'YYYY-MM-DD hh:mm:ss ZZ'        => 'YYYY-MM-DD hh:mm:ss ZZ',
                            'YYYYMMDDTHH:mm'                => 'YYYYMMDDTHH:mm',
                            'YYYYMMDDThhmmss'               => 'YYYYMMDDThhmmss',
                            'YYYY-MM-DDTHH:mm'              => 'YYYY-MM-DDTHH:mm',
                            'YYYY-MM-DDThhmmss'             => 'YYYY-MM-DDThhmmss',
                            'YYYYMMDDTHH:mm Z'              => 'YYYYMMDDTHH:mm Z',
                            'YYYYMMDDThhmmss Z'             => 'YYYYMMDDThhmmss Z',
                            'YYYY-MM-DDTHH:mm Z'            => 'YYYY-MM-DDTHH:mm Z',
                            'YYYY-MM-DDThhmmss Z'           => 'YYYY-MM-DDThhmmss Z',
                            'YYYYMMDDTHH:mm ZZ'             => 'YYYYMMDDTHH:mm ZZ',
                            'YYYYMMDDThhmmss ZZ'            => 'YYYYMMDDThhmmss ZZ',
                            'YYYY-MM-DDTHH:mm ZZ'           => 'YYYY-MM-DDTHH:mm ZZ',
                            'YYYY-MM-DDThhmmss ZZ'          => 'YYYY-MM-DDThhmmss ZZ',
                            'DD MM YY HH:mm'                => 'DD MM YY HH:mm',
                            'DD.MM.YY HH:mm'                => 'DD.MM.YY HH:mm',
                            'DD-MM-YY HH:mm'                => 'DD-MM-YY HH:mm',
                            'DD/MM/YY HH:mm'                => 'DD/MM/YY HH:mm',
                            'DD MM YYYY HH:mm'              => 'DD MM YYYY HH:mm',
                            'DD.MM.YYYY HH:mm'              => 'DD.MM.YYYY HH:mm',
                            'DD-MM-YYYY HH:mm'              => 'DD-MM-YYYY HH:mm',
                            'DD/MM/YYYY HH:mm'              => 'DD/MM/YYYY HH:mm',
                            'DD MMM YYYY HH:mm'             => 'DD MMM YYYY HH:mm',
                            'DD-MMM-YYYY HH:mm'             => 'DD-MMM-YYYY HH:mm',
                            'DD/MMM/YYYY HH:mm'             => 'DD/MMM/YYYY HH:mm',
                            'DD MMMM YYYY HH:mm'            => 'DD MMMM YYYY HH:mm',
                            'DD-MMMM-YYYY HH:mm'            => 'DD-MMMM-YYYY HH:mm',
                            'DD/MMMM/YYYY HH:mm'            => 'DD/MMMM/YYYY HH:mm',
                            'DD MM YYYY HH:mm:ss'           => 'DD MM YYYY HH:mm:ss',
                            'DD.MM.YYYY HH:mm:ss'           => 'DD.MM.YYYY HH:mm:ss',
                            'DD-MM-YYYY HH:mm:ss'           => 'DD-MM-YYYY HH:mm:ss',
                            'DD/MM/YYYY HH:mm:ss'           => 'DD/MM/YYYY HH:mm:ss',
                            'DD MMM YYYY HH:mm:ss'          => 'DD MMM YYYY HH:mm:ss',
                            'DD-MMM-YYYY HH:mm:ss'          => 'DD-MMM-YYYY HH:mm:ss',
                            'DD/MMM/YYYY HH:mm:ss'          => 'DD/MMM/YYYY HH:mm:ss',
                            'DD MMMM YYYY HH:mm:ss'         => 'DD MMMM YYYY HH:mm:ss',
                            'DD-MMMM-YYYY HH:mm:ss'         => 'DD-MMMM-YYYY HH:mm:ss',
                            'DD/MMMM/YYYY HH:mm:ss'         => 'DD/MMMM/YYYY HH:mm:ss',
                            'D MM YY HH:mm'                 => 'D MM YY HH:mm',
                            'D.MM.YY HH:mm'                 => 'D.MM.YY HH:mm',
                            'D-MM-YY HH:mm'                 => 'D-MM-YY HH:mm',
                            'D/MM/YY HH:mm'                 => 'D/MM/YY HH:mm',
                            'D MM YYYY HH:mm'               => 'D MM YYYY HH:mm',
                            'D.MM.YYYY HH:mm'               => 'D.MM.YYYY HH:mm',
                            'D-MM-YYYY HH:mm'               => 'D-MM-YYYY HH:mm',
                            'D/MM/YYYY HH:mm'               => 'D/MM/YYYY HH:mm',
                            'D MMM YYYY HH:mm'              => 'D MMM YYYY HH:mm',
                            'D-MMM-YYYY HH:mm'              => 'D-MMM-YYYY HH:mm',
                            'D/MMM/YYYY HH:mm'              => 'D/MMM/YYYY HH:mm',
                            'D MMMM YYYY HH:mm'             => 'D MMMM YYYY HH:mm',
                            'D-MMMM-YYYY HH:mm'             => 'D-MMMM-YYYY HH:mm',
                            'D/MMMM/YYYY HH:mm'             => 'D/MMMM/YYYY HH:mm',
                            'D MM YYYY HH:mm:ss'            => 'D MM YYYY HH:mm:ss',
                            'D.MM.YYYY HH:mm:ss'            => 'D.MM.YYYY HH:mm:ss',
                            'D-MM-YYYY HH:mm:ss'            => 'D-MM-YYYY HH:mm:ss',
                            'D/MM/YYYY HH:mm:ss'            => 'D/MM/YYYY HH:mm:ss',
                            'D MMM YYYY HH:mm:ss'           => 'D MMM YYYY HH:mm:ss',
                            'D-MMM-YYYY HH:mm:ss'           => 'D-MMM-YYYY HH:mm:ss',
                            'D/MMM/YYYY HH:mm:ss'           => 'D/MMM/YYYY HH:mm:ss',
                            'D MMMM YYYY HH:mm:ss'          => 'D MMMM YYYY HH:mm:ss',
                            'D-MMMM-YYYY HH:mm:ss'          => 'D-MMMM-YYYY HH:mm:ss',
                            'D/MMMM/YYYY HH:mm:ss'          => 'D/MMMM/YYYY HH:mm:ss',
                            'ddd, DD MM YY HH:mm'           => 'ddd, DD MM YY HH:mm',
                            'ddd, DD.MM.YY HH:mm'           => 'ddd, DD.MM.YY HH:mm',
                            'ddd, DD-MM-YY HH:mm'           => 'ddd, DD-MM-YY HH:mm',
                            'ddd, DD/MM/YYYY HH:mm'         => 'ddd, DD/MM/YY HH:mm',
                            'ddd, DD MM YY HH:mm:ss'        => 'ddd, DD MM YY HH:mm:ss',
                            'ddd, DD.MM.YY HH:mm:ss'        => 'ddd, DD.MM.YY HH:mm:ss',
                            'ddd, DD-MM-YY HH:mm:ss'        => 'ddd, DD-MM-YY HH:mm:ss',
                            'ddd, DD/MM/YY HH:mm:ss'        => 'ddd, DD/MM/YY HH:mm:ss',
                            'ddd, DD MM YY HH:mm:ss Z'      => 'ddd, DD MM YY HH:mm:ss Z',
                            'ddd, DD.MM.YY HH:mm:ss Z'      => 'ddd, DD.MM.YY HH:mm:ss Z',
                            'ddd, DD-MM-YY HH:mm:ss Z'      => 'ddd, DD-MM-YY HH:mm:ss Z',
                            'ddd, DD/MM/YY HH:mm:ss Z'      => 'ddd, DD/MM/YY HH:mm:ss Z',
                            'ddd, DD MM YY HH:mm:ss ZZ'     => 'ddd, DD MM YY HH:mm:ss ZZ',
                            'ddd, DD.MM.YY HH:mm:ss ZZ'     => 'ddd, DD.MM.YY HH:mm:ss ZZ',
                            'ddd, DD-MM-YY HH:mm:ss ZZ'     => 'ddd, DD-MM-YY HH:mm:ss ZZ',
                            'ddd, DD/MM/YY HH:mm:ss ZZ'     => 'ddd, DD/MM/YY HH:mm:ss ZZ',
                            'ddd, D MM YY HH:mm'            => 'ddd, D MM YY HH:mm',
                            'ddd, D.MM.YY HH:mm'            => 'ddd, D.MM.YY HH:mm',
                            'ddd, D-MM-YY HH:mm'            => 'ddd, D-MM-YY HH:mm',
                            'ddd, D/MM/YYYY HH:mm'          => 'ddd, D/MM/YY HH:mm',
                            'ddd, D MM YY HH:mm:ss'         => 'ddd, D MM YY HH:mm:ss',
                            'ddd, D.MM.YY HH:mm:ss'         => 'ddd, D.MM.YY HH:mm:ss',
                            'ddd, D-MM-YY HH:mm:ss'         => 'ddd, D-MM-YY HH:mm:ss',
                            'ddd, D/MM/YY HH:mm:ss'         => 'ddd, D/MM/YY HH:mm:ss',
                            'ddd, D MM YY HH:mm:ss Z'       => 'ddd, D MM YY HH:mm:ss Z',
                            'ddd, D.MM.YY HH:mm:ss Z'       => 'ddd, D.MM.YY HH:mm:ss Z',
                            'ddd, D-MM-YY HH:mm:ss Z'       => 'ddd, D-MM-YY HH:mm:ss Z',
                            'ddd, D/MM/YY HH:mm:ss Z'       => 'ddd, D/MM/YY HH:mm:ss Z',
                            'ddd, D MM YY HH:mm:ss ZZ'      => 'ddd, D MM YY HH:mm:ss ZZ',
                            'ddd, D.MM.YY HH:mm:ss ZZ'      => 'ddd, D.MM.YY HH:mm:ss ZZ',
                            'ddd, D-MM-YY HH:mm:ss ZZ'      => 'ddd, D-MM-YY HH:mm:ss ZZ',
                            'ddd, D/MM/YY HH:mm:ss ZZ'      => 'ddd, D/MM/YY HH:mm:ss ZZ',
                            'ddd, MM DD YY HH:mm'           => 'ddd, MM DD YY HH:mm',
                            'ddd, MM.DD.YY HH:mm'           => 'ddd, MM.DD.YY HH:mm',
                            'ddd, MM-DD-YY HH:mm'           => 'ddd, MM-DD-YY HH:mm',
                            'ddd, MM/DD/YY HH:mm'           => 'ddd, MM/DD/YY HH:mm',
                            'ddd, MM DD YY HH:mm:ss'        => 'ddd, MM DD YY HH:mm:ss',
                            'ddd, MM.DD.YY HH:mm:ss'        => 'ddd, MM.DD.YY HH:mm:ss',
                            'ddd, MM-DD-YY HH:mm:ss'        => 'ddd, MM-DD-YY HH:mm:ss',
                            'ddd, MM/DD/YY HH:mm:ss'        => 'ddd, MM/DD/YY HH:mm:ss',
                            'ddd, MM DD YY HH:mm:ss Z'      => 'ddd, MM DD YY HH:mm:ss Z',
                            'ddd, MM.DD.YY HH:mm:ss Z'      => 'ddd, MM.DD.YY HH:mm:ss Z',
                            'ddd, MM-DD-YY HH:mm:ss Z'      => 'ddd, MM-DD-YY HH:mm:ss Z',
                            'ddd, MM/DD/YY HH:mm:ss Z'      => 'ddd, MM/DD/YY HH:mm:ss Z',
                            'ddd, MM DD YY HH:mm:ss ZZ'     => 'ddd, MM DD YY HH:mm:ss ZZ',
                            'ddd, MM.DD.YY HH:mm:ss ZZ'     => 'ddd, MM.DD.YY HH:mm:ss ZZ',
                            'ddd, MM-DD-YY HH:mm:ss ZZ'     => 'ddd, MM-DD-YY HH:mm:ss ZZ',
                            'ddd, MM/DD/YY HH:mm:ss ZZ'     => 'ddd, MM/DD/YY HH:mm:ss ZZ',
                            'ddd, DD MMM YYYY HH:mm'        => 'ddd, DD MMM YYYY HH:mm',
                            'ddd, DD-MMM-YYYY HH:mm'        => 'ddd, DD-MMM-YYYY HH:mm',
                            'ddd, DD/MMM/YYYY HH:mm'        => 'ddd, DD/MMM/YYYY HH:mm',
                            'ddd, DD MMM YYYY HH:mm:ss'     => 'ddd, DD MMM YYYY HH:mm:ss',
                            'ddd, DD-MMM-YYYY HH:mm:ss'     => 'ddd, DD-MMM-YYYY HH:mm:ss',
                            'ddd, DD/MMM/YYYY HH:mm:ss'     => 'ddd, DD/MMM/YYYY HH:mm:ss',
                            'ddd, DD MMM YYYY HH:mm:ss Z'   => 'ddd, DD MMM YYYY HH:mm:ss Z',
                            'ddd, DD-MMM-YYYY HH:mm:ss Z'   => 'ddd, DD-MMM-YYYY HH:mm:ss Z',
                            'ddd, DD/MMM/YYYY HH:mm:ss Z'   => 'ddd, DD/MMM/YYYY HH:mm:ss Z',
                            'ddd, DD MMM YYYY HH:mm:ss ZZ'  => 'ddd, DD MMM YYYY HH:mm:ss ZZ',
                            'ddd, DD-MMM-YYYY HH:mm:ss ZZ'  => 'ddd, DD-MMM-YYYY HH:mm:ss ZZ',
                            'ddd, DD/MMM/YYYY HH:mm:ss ZZ'  => 'ddd, DD/MMM/YYYY HH:mm:ss ZZ',
                            'ddd, MMM DD YYYY HH:mm'        => 'ddd, MMM DD YYYY HH:mm',
                            'ddd, MMM-DD-YYYY HH:mm'        => 'ddd, MMM-DD-YYYY HH:mm',
                            'ddd, MMM/DD/YYYY HH:mm'        => 'ddd, MMM/DD/YYYY HH:mm',
                            'ddd, MMM DD YYYY HH:mm:ss'     => 'ddd, MMM DD YYYY HH:mm:ss',
                            'ddd, MMM-DD-YYYY HH:mm:ss'     => 'ddd, MMM-DD-YYYY HH:mm:ss',
                            'ddd, MMM/DD/YYYY HH:mm:ss'     => 'ddd, MMM/DD/YYYY HH:mm:ss',
                            'ddd, MMM DD YYYY HH:mm:ss Z'   => 'ddd, MMM DD YYYY HH:mm:ss Z',
                            'ddd, MMM-DD-YYYY HH:mm:ss Z'   => 'ddd, MMM-DD-YYYY HH:mm:ss Z',
                            'ddd, MMM/DD/YYYY HH:mm:ss Z'   => 'ddd, MMM/DD/YYYY HH:mm:ss Z',
                            'ddd, MMM DD YYYY HH:mm:ss ZZ'  => 'ddd, MMM DD YYYY HH:mm:ss ZZ',
                            'ddd, MMM-DD-YYYY HH:mm:ss ZZ'  => 'ddd, MMM-DD-YYYY HH:mm:ss ZZ',
                            'ddd, MMM/DD/YYYY HH:mm:ss ZZ'  => 'ddd, MMM/DD/YYYY HH:mm:ss ZZ',
                            'ddd, DD MMMM YYYY HH:mm'       => 'ddd, DD MMMM YYYY HH:mm',
                            'ddd, DD-MMMM-YYYY HH:mm'       => 'ddd, DD-MMMM-YYYY HH:mm',
                            'ddd, DD/MMMM/YYYY HH:mm'       => 'ddd, DD/MMMM/YYYY HH:mm',
                            'ddd, DD MMMM YYYY HH:mm:ss'    => 'ddd, DD MMMM YYYY HH:mm:ss',
                            'ddd, DD-MMMM-YYYY HH:mm:ss'    => 'ddd, DD-MMMM-YYYY HH:mm:ss',
                            'ddd, DD/MMMM/YYYY HH:mm:ss'    => 'ddd, DD/MMMM/YYYY HH:mm:ss',
                            'ddd, DD MMMM YYYY HH:mm:ss Z'  => 'ddd, DD MMMM YYYY HH:mm:ss Z',
                            'ddd, DD-MMMM-YYYY HH:mm:ss Z'  => 'ddd, DD-MMMM-YYYY HH:mm:ss Z',
                            'ddd, DD/MMMM/YYYY HH:mm:ss Z'  => 'ddd, DD/MMMM/YYYY HH:mm:ss Z',
                            'ddd, DD MMMM YYYY HH:mm:ss ZZ' => 'ddd, DD MMMM YYYY HH:mm:ss ZZ',
                            'ddd, DD-MMMM-YYYY HH:mm:ss ZZ' => 'ddd, DD-MMMM-YYYY HH:mm:ss ZZ',
                            'ddd, DD/MMMM/YYYY HH:mm:ss ZZ' => 'ddd, DD/MMMM/YYYY HH:mm:ss ZZ',
                            'ddd, MMMM DD YYYY HH:mm'       => 'ddd, MMMM DD YYYY HH:mm',
                            'ddd, MMMM-DD-YYYY HH:mm'       => 'ddd, MMMM-DD-YYYY HH:mm',
                            'ddd, MMMM/DD/YYYY HH:mm'       => 'ddd, MMMM/DD/YYYY HH:mm',
                            'ddd, MMMM DD YYYY HH:mm:ss'    => 'ddd, MMMM DD YYYY HH:mm:ss',
                            'ddd, MMMM-DD-YYYY HH:mm:ss'    => 'ddd, MMMM-DD-YYYY HH:mm:ss',
                            'ddd, MMMM/DD/YYYY HH:mm:ss'    => 'ddd, MMMM/DD/YYYY HH:mm:ss',
                            'ddd, MMMM DD YYYY HH:mm:ss Z'  => 'ddd, MMMM DD YYYY HH:mm:ss Z',
                            'ddd, MMMM-DD-YYYY HH:mm:ss Z'  => 'ddd, MMMM-DD-YYYY HH:mm:ss Z',
                            'ddd, MMMM/DD/YYYY HH:mm:ss Z'  => 'ddd, MMMM/DD/YYYY HH:mm:ss Z',
                            'ddd, MMMM DD YYYY HH:mm:ss ZZ' => 'ddd, MMMM DD YYYY HH:mm:ss ZZ',
                            'ddd, MMMM-DD-YYYY HH:mm:ss ZZ' => 'ddd, MMMM-DD-YYYY HH:mm:ss ZZ',
                            'ddd, MMMM/DD/YYYY HH:mm:ss ZZ' => 'ddd, MMMM/DD/YYYY HH:mm:ss ZZ',
                        ),
                        ),
                        array(
                            'title' => __( 'Example:', 'giveaways-for-woocommerce' ),
                            'value' => 'YYYY-MM-DD HH:mm:ss',
                            'type'  => 'label_dcp',
                            'class' => 'sse-exampel-date-time',
                            'desc'  => '',
                            'id'    => 'woocommerce_date_example_calendar',
                        ),
                        array(
                            'title'    => __( 'Step for time (min)', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Setting the time scale in the calendar.', 'giveaways-for-woocommerce' ),
                            'id'       => 'dcp_step_time_sse',
                            'type'     => 'number',
                            'css'      => 'width:6em;',
                            'default'  => '10',
                            'autoload' => false,
                            'desc_tip' => true,
                        ),
                        array(
                            'type' => 'sectionend',
                            'id'   => 'sse_calendar_template_options',
                        ),
                        //Setting up coupon columns.
                        array(
                            'title' => __( 'Column list of the coupons', 'giveaways-for-woocommerce' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'dcp_list_options_sse',
                        ),
                        array(
                            'title'    => __( 'Notification', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Add a column for information about notifications distribution', 'giveaways-for-woocommerce' ),
                            'id'       => 'dcp_columns_notices_sse',
                            'type'     => 'checkbox',
                            'default'  => false,
                            'autoload' => false,
                            'desc_tip' => true,
                        ),
                        array(
                            'title'    => __( 'CRON', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Add a column for information about setting the CRON task', 'giveaways-for-woocommerce' ),
                            'id'       => 'dcp_columns_cron_sse',
                            'type'     => 'checkbox',
                            'default'  => false,
                            'autoload' => false,
                            'desc_tip' => true,
                        ),
                        array(
                            'title'    => __( 'The notification status', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Add a column for notification status information', 'giveaways-for-woocommerce' ),
                            'id'       => 'dcp_columns_status_sse',
                            'type'     => 'checkbox',
                            'default'  => false,
                            'autoload' => false,
                            'desc_tip' => true,
                        ),
                        array(
                            'type' => 'sectionend',
                            'id'   => 'dcp_list_template_options_sse',
                        ),
                        //Clear button.
                        array(
                            'title' => __( 'Confirmation of mailing', 'giveaways-for-woocommerce' ),
                            'type'  => 'title',
                            'desc'  => '',
                            'id'    => 'dcp_button_sse',
                        ),
                        array(
                            'title'    => __( 'Clearing mailing confirmations', 'giveaways-for-woocommerce' ),
                            'desc'     => __( 'Delete all messages to the administrator with confirmation of actions for notifications.', 'giveaways-for-woocommerce' ),
                            'id'       => 'DCP_AllDelAdminNotif_SSE',
                            'type'     => 'button_dcp',
                            'class'    => 'button-primary woocommerce-save-button',
                            'value'    => __( 'Clean', 'giveaways-for-woocommerce' ),
                            'default'  => false,
                            'autoload' => false,
                            'desc_tip' => true,
                        ),
                        array(
                            'type' => 'sectionend',
                            'id'   => 'dcp_button_template_sse',
                        ),
                    ) );
                }
            }
            if ( 'notices' === $current_section ) {
                $settings = apply_filters( 'woocommerce_dispatch_coupons_emails_settings', array(
                    array(
                        'title' => __( 'Navigation', 'woocommerce' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'navigation_options',
                    ),
                    array(
                        'title'    => __( 'Number of notifications', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Number of notifications to download at a time.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_notif_navig',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '10',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'type' => 'sectionend',
                        'id'   => 'navigation_template_options',
                    ),
                    array(
                        'title' => __( 'Main notification area', 'woocommerce' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'notices_options',
                    ),
                    array(
                        'title'    => __( 'Background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The background color of the main area notification(Example: background-color: #f1f1f1;).', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_back_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#f9f9f9',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'The color of the top border', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Color of the upper border of the main notification area (Example: border-top-color: #ffb900;).', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_bord_top_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#aeb3b9',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Upper indent(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Distance between notifications(Example: margin-top: 25px;).', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_marg_bottom',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '25',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Left indent text(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The left indentation of the text from the border of notification (Example: padding-left: 25px;).', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_pad_left',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '15',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Setting up CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Toggles on the ability to customize the main area of the notification by the css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_rules_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Ruls CSS', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This string is placed in the "style" attribute of the corresponding "DIV" tag"', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'background-color: #f9f9f9; border-top-style: solid; border-top-color: #aeb3b9; margin-bottom: 25px;
					                    padding: 10px 10px 10px 15px; border-bottom-right-radius: 15px; border-bottom-left-radius: 15px;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'type' => 'sectionend',
                        'id'   => 'notices_template_options',
                    ),
                    //Customize the notification header.
                    array(
                        'title' => __( 'The title of the notification', 'giveaways-for-woocommerce' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'notices_options_headline',
                    ),
                    array(
                        'title'    => __( 'Text', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The title text may contain a shortcode"dcp_date"', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_text',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => '<span style="font-family:arial;color:#23282D;font-style: italic;font-weight: bold">[dcp_date local="default" format="F j, Y, G:i"]</span>',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The background color of the title', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#f1f1f1',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Height(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The height of the title in px', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_height',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '50',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Upper and lower indent(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Indent text from the top and bottom of the title', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_padding_tb',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '11',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Right and left indent(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Text indents from the right and left borders of the title', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_padding_rl',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '10',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Horizontal alignment', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Horizontal alignment of the title', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_horiz_alignm',
                        'default'  => 'left',
                        'type'     => 'select',
                        'class'    => 'wc-enhanced-select',
                        'css'      => 'min-width: 350px;',
                        'desc_tip' => true,
                        'options'  => array(
                        'left'   => __( 'left', 'giveaways-for-woocommerce' ),
                        'right'  => __( 'right', 'giveaways-for-woocommerce' ),
                        'center' => __( 'center', 'giveaways-for-woocommerce' ),
                    ),
                    ),
                    array(
                        'title'    => __( 'Setting CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to customize the external area (DIV) of the notification title with css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_rules_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This string is placed in the "style" attribute of the corresponding "DIV" tag".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_div_headline_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'background-color: #f1f1f1; height: 50px; padding: 10px 11px; text-align: left;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'The width of the inner area(%)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'By adjusting the inner area, you can specify that the text does not go beyond the middle of the title(50%), and moved to the second line.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_width',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '100',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Text color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Title text color.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_col_font',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#23282d',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Font size(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Title font size в px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_font_size',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '18',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Setting up using CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to customize the internal area (div) of the notification header with css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_rules_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This line is placed in the "style" attribute of the corresponding "div" tag".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_headline_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'width: 100%; color: #23282d; font-size: 18px; text-align: right;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'type' => 'sectionend',
                        'id'   => 'notices_temp_opt_headline',
                    ),
                    //Customize the button to delete notifications.
                    array(
                        'title' => __( 'Delete notification button', 'giveaways-for-woocommerce' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'notices_options_button',
                    ),
                    array(
                        'title'    => __( 'Text', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Text of the delete notification button.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_button_del_text',
                        'type'     => 'text',
                        'css'      => 'width:50%;',
                        'default'  => 'DEL',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The background color of the delete notification button.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_del_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#0085ba',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Hover background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The background color of the delete notification button when the mouse pointer is over.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_hover_button_del_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#0073aa',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Width(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The width of the delete notification button in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_del_width',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '150',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Height(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The height of the delete notification button in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_del_height',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '25',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Text color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The text color of the notification deletion button .', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_del_col_font',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#ffffff',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Font size(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The font size for the text on the delete notification button in the px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_but_del_font_size',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '15',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Setting up using CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to customize the button to delete notifications by css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_rules_del_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Enable pointing at CSS', 'giveaways-for-woocommerce' ),
                        'desc'     => __( '!!! The colors from the "Background color" and "Hover background color" fields will be used.".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_del_js',
                        'type'     => 'checkbox',
                        'default'  => true,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This line is placed in the attribute "style" of the corresponding tag "button".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_del_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'line-height: 25px; padding: 0px; text-align: center; margin: 0px; background-color: #0085ba; width: 150px; height: 25px;
					                color: #ffffff; font-size: 15px; -webkit-border-radius 0; -moz-border-radius 0; border-radius: 0;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Upper indent(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The top indent of the delete notification button from the main text in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_div_del_margin',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '25',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Horizontal alignment', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Horizontal alignment of the notification delete button.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_del_horiz_alignm',
                        'default'  => 'right',
                        'type'     => 'select',
                        'class'    => 'wc-enhanced-select',
                        'css'      => 'min-width: 350px;',
                        'desc_tip' => true,
                        'options'  => array(
                        'left'   => __( 'left', 'giveaways-for-woocommerce' ),
                        'right'  => __( 'right', 'giveaways-for-woocommerce' ),
                        'center' => __( 'center', 'giveaways-for-woocommerce' ),
                    ),
                    ),
                    array(
                        'title'    => __( 'Setting up using CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to configure the external area (div) of the notification removal button by cs rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_div_rules_del_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This line is placed in the attribute "style" of the corresponding tag "div".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_div_del_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'widtx:100%; clear: both; margin-top: 25px; text-align: left;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'type' => 'sectionend',
                        'id'   => 'notices_temp_opt_button_del',
                    ),
                    // Button to load previous notifications.
                    array(
                        'title' => __( 'Button to load previous notifications', 'giveaways-for-woocommerce' ),
                        'type'  => 'title',
                        'desc'  => '',
                        'id'    => 'notices_options_button',
                    ),
                    array(
                        'title'    => __( 'Text', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The text of the download button for previous notifications.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_ncp_button_next_text',
                        'type'     => 'text',
                        'css'      => 'width:50%;',
                        'default'  => 'PREVIOUS',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Background color of the download button for previous notifications.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_next_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#0085ba',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Hover background color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Background color of the download button for previous notifications when the mouse pointer is over.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_hover_button_next_col',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#0073aa',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Width(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The width of the download button for previous notifications in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_next_width',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '150',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Height(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The height of the download button for previous notifications in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_next_height',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '25',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Text color', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The color of the text of the download button for previous notifications.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_button_next_col_font',
                        'type'     => 'color',
                        'css'      => 'width:6em;',
                        'default'  => '#ffffff',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Font size(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The font size for the text on the download button of previous notifications in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_but_next_font_size',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '15',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Setting up using CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to configure the download button for previous notifications by css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_rules_next_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Enable pointing at CSS', 'giveaways-for-woocommerce' ),
                        'desc'     => __( '!!! The colors from the "Background color" and "Hover background color" fields will be used.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_rules_next_js',
                        'type'     => 'checkbox',
                        'default'  => true,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This line is placed in the attribute "style" of the corresponding tag "button".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_button_next_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'line-height: 25px; padding: 0px; text-align: center; margin: 0px; background-color: #0085ba; width: 150px; height: 25px;
					        color: #ffffff; font-size: 15px; -webkit-border-radius 0; -moz-border-radius 0; border-radius: 0;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Upper indent(px)', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'The top indent of the download button for previous notifications from the notification list in px.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_n_div_next_margin',
                        'type'     => 'number',
                        'css'      => 'width:6em;',
                        'default'  => '18',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'Horizontal Alignment', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Horizontal alignment buttons download previous notification.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_next_horiz_alignm',
                        'default'  => 'left',
                        'type'     => 'select',
                        'class'    => 'wc-enhanced-select',
                        'css'      => 'min-width: 350px;',
                        'desc_tip' => true,
                        'options'  => array(
                        'left'   => __( 'left', 'giveaways-for-woocommerce' ),
                        'right'  => __( 'right', 'giveaways-for-woocommerce' ),
                        'center' => __( 'center', 'giveaways-for-woocommerce' ),
                    ),
                    ),
                    array(
                        'title'    => __( 'Setting up using CSS rules', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'Switches to the ability to configure the external area (div) of the download button for previous notifications by the css rules.', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_div_rules_next_css',
                        'type'     => 'checkbox',
                        'default'  => false,
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'title'    => __( 'CSS ruls', 'giveaways-for-woocommerce' ),
                        'desc'     => __( 'This line is placed in the attribute "style" of the corresponding tag "div".', 'giveaways-for-woocommerce' ),
                        'id'       => 'sse_div_next_code_css',
                        'type'     => 'textarea',
                        'css'      => 'width:75%;',
                        'default'  => 'margin-top: 50px; clear: both; margin-top: 25px; text-align: right;',
                        'autoload' => false,
                        'desc_tip' => true,
                    ),
                    array(
                        'type' => 'sectionend',
                        'id'   => 'notices_temp_opt_button_next',
                    ),
                ) );
            }
            return apply_filters( 'woocommerce_get_settings_' . $this->id, $settings, $current_section );
        }
        
        /**
         * Output the settings.
         */
        public function output()
        {
            global  $current_section ;
            $settings = $this->get_settings( $current_section );
            WC_Admin_Settings::output_fields( $settings );
        }
        
        /**
         * Save settings.
         */
        public function save()
        {
            global  $current_section ;
            WC_Admin_Settings::save_fields( $this->get_settings( $current_section ) );
        }
    
    }
}
return new WC_Settings_Dispatch_Coupons();