<?php

/**
 * Create additional tabs with the controls on the page "Add a new coupon" and "Edit coupon".
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */
if ( !defined( 'ABSPATH' ) ) {
    exit;
}
class DCP_TAB_COUPON
{
    /**
     * Hook in ajax handlers.
     */
    public static function init()
    {
        add_filter( 'woocommerce_coupon_data_tabs', array( __CLASS__, 'custom_coupon_tabs' ), 10 );
        add_action(
            'woocommerce_coupon_data_panels',
            array( __CLASS__, 'custom_coupon_panels' ),
            10,
            2
        );
    }
    
    /**
     * Create additional tabs on the "Add a new coupon" and "Edit coupon" page.
     */
    function custom_coupon_tabs( $arr_tabs )
    {
        $arr_tabs['dispatch_notices'] = array(
            'label'  => __( 'Notification distribution', 'giveaways-for-woocommerce' ),
            'target' => 'coupon_dispatch_notices',
            'class'  => '',
        );
        return $arr_tabs;
    }
    
    /**
     * Add items to the appropriate tabs.
     */
    function custom_coupon_panels( $coupon_id, $coupon )
    {
        //Display notification elements
        ?>
    	<div id="coupon_dispatch_notices" class="panel woocommerce_options_panel">
    		<?php 
        //notices_status
        woocommerce_wp_text_input( array(
            'id'    => 'dcp_notices_status_sse',
            'name'  => 'dcp_notices_status_sse',
            'label' => __( 'Notification Status', 'giveaways-for-woocommerce' ),
        ) );
        //notices_status_id
        woocommerce_wp_text_input( array(
            'id'    => 'dcp_notices_status_id_sse',
            'name'  => 'dcp_notices_status_id_sse',
            'style' => 'display:none;',
            'label' => '',
        ) );
        //save_user_id
        woocommerce_wp_text_input( array(
            'id'    => 'dcp_save_user_id_sse',
            'name'  => 'dcp_save_user_id_sse',
            'style' => 'display:none;',
            'label' => '',
        ) );
        //Enable notices for coupon
        woocommerce_wp_checkbox( array(
            'id'          => 'dcp_notices_coupon_sse',
            'label'       => __( 'Notification ', 'giveaways-for-woocommerce' ),
            'description' => __( 'Enable / disable notifications.', 'giveaways-for-woocommerce' ),
        ) );
        //Enable CRON for notices coupon
        woocommerce_wp_checkbox( array(
            'id'          => 'dcp_notices_coupon_cron_sse',
            'label'       => __( 'CRON', 'giveaways-for-woocommerce' ),
            'description' => __( 'Enable / disable CRON .', 'giveaways-for-woocommerce' ),
        ) );
        //Enable notices full cleaning
        woocommerce_wp_checkbox( array(
            'id'          => 'dcp_notices_full_cleaning_sse',
            'label'       => __( 'Complete cleaning', 'giveaways-for-woocommerce' ),
            'description' => __( 'Enable / disable complete cleaning.', 'giveaways-for-woocommerce' ),
        ) );
        //Date of dispatch email
        $coupon_sse = new DCP_CP_NTC( $coupon_id );
        $expiry_date = ( $coupon_sse->get_date_dispatch_notices() ? $coupon_sse->get_date_dispatch_notices() : '' );
        $cformat = WC_Admin_Settings::get_option( 'woocommerce_date_format_calendar' );
        woocommerce_wp_text_input( array(
            'id'                => 'dcp_date_dispatch_notices_sse',
            'value'             => esc_attr( $expiry_date ),
            'label'             => __( 'Date for CRON', 'giveaways-for-woocommerce' ),
            'placeholder'       => $cformat,
            'description'       => '',
            'class'             => 'sse-datetime-picker-notices',
            'custom_attributes' => array(
            'autocomplete' => 'off',
        ),
        ) );
        
        if ( $coupon_sse->get_date_dispatch_notices_u() ) {
            $expiry_date_u = (int) $coupon_sse->get_date_dispatch_notices_u()->date( 'U' ) - (current_time( 'timestamp' ) - time());
        } else {
            $expiry_date_u = '';
        }
        
        woocommerce_wp_text_input( array(
            'id'    => 'dcp_date_dispatch_notices_u_sse',
            'value' => esc_attr( $expiry_date_u ),
            'style' => 'display:none;',
            'class' => 'sse-datetime-picker-notices-u',
            'label' => '',
        ) );
        // Inserting the TinyMCE Editor
        $editor_notices = $coupon_sse->get_editor_notices();
        echo  '<p class="form-field dcp_editor_notices_sse_field wp-editor-area">' ;
        wp_editor( htmlspecialchars_decode( $editor_notices ), 'dcp_editor_notices_sse', array(
            'textarea_name'     => 'dcp_editor_notices_sse',
            'drag_drop_upload'  => true,
            'tabfocus_elements' => 'content-html,save-post',
            'editor_height'     => 400,
            'tinymce'           => array(
            'resize'             => true,
            'wp_autoresize_on'   => true,
            'add_unload_trigger' => false,
        ),
        ) );
        echo  '</p>' ;
        woocommerce_wp_text_input( array(
            'id'    => 'dcp_list_emails_n_sse',
            'name'  => 'dcp_list_emails_n_sse',
            'label' => __( 'Email of the Users', 'giveaways-for-woocommerce' ),
        ) );
        ?>
    	</div>

    	<?php 
    }

}
DCP_TAB_COUPON::init();