<?php
/**
 * AJAX function(free)
 *
 * @package  Sending coupon notifications/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class DCP_AJAX {

    /**
     * Hook in ajax handlers.
     */
    public static function init () {
    self::add_ajax_events();
    }


    /**
    * Hook in methods.
    */
    public static function add_ajax_events() {
    	$ajax_events = array(
    		'dispatch_coupons'                              => false,
    		'ok_notices_dispatch'                           => false,
    		'no_notices_dispatch'                           => false,
    		'notices_next'                                  => false,
    		'notices_del'                                   => false,
    		'notices_new'                                   => false,
    		'all_del_admin_notif_dcp'			=> false,
    	);

    	foreach ( $ajax_events as $ajax_event => $nopriv ) {
    		add_action( 'wp_ajax_sse_' . $ajax_event, array( __CLASS__, $ajax_event ) );

    		if ( $nopriv ) {
    			add_action( 'wp_ajax_nopriv_sse_' . $ajax_event, array( __CLASS__, $ajax_event ) );

    			// WC AJAX can be used for frontend ajax requests.
    			add_action( 'wc_ajax_' . $ajax_event, array( __CLASS__, $ajax_event ) );
    		}
    	}
    }

    /**
    * Getting the value of the parameters (localization, date format) through AJAX to
    * customize the calendar / hours.
    */
    public static function dispatch_coupons() {
        $nonce = $_POST['nonce'];

        if (!wp_verify_nonce($nonce, 'myajax-nonce'))
          die('Stop!');

        $calendar_options['local']  = WC_Admin_Settings::get_option('woocommerce_localization_calendar');
        $calendar_options['format'] = WC_Admin_Settings::get_option('woocommerce_date_format_calendar');
        $calendar_options['step_time'] = WC_Admin_Settings::get_option('dcp_step_time_sse');

        echo(json_encode($calendar_options));
        wp_die();
    }



    /**
    * Confirmation of sending notifications.
    */
    public static function ok_notices_dispatch() {
        $nonce     = $_POST['nonce'];
        $coupon_id = isset($_POST['idCoupon']) ? wc_clean($_POST['idCoupon']): '';
        $user_ID   = isset($_POST['userID']) ? wc_clean($_POST['userID']): '';
        $notif_act   = isset($_POST['notifAct']) ? wc_clean($_POST['notifAct']): '';

        if (!wp_verify_nonce($nonce, 'myajax-nonce'))
          die('Stop!');

        $user       = get_userdata($user_ID);
        $user_login = $user->user_login;

        $current_user       = wp_get_current_user();
        $current_user_ID    = $current_user->ID;
        $current_user_login = $current_user->user_login;
        $current_user_roles = $current_user->roles;
        $current_user_roles_str = implode(',', $current_user_roles);

        $coupon_sse = new DCP_CP_NTC($coupon_id);
        $email_coupon_cron = $coupon_sse->get_notices_coupon_cron();
        $coupon_description = $coupon_sse->get_editor_notices();
        $save_user_id = $coupon_sse->get_save_user_id();

        $coupon             = new WC_Coupon($coupon_id);
        $coupon_code        = $coupon->get_code();

        $messag_headr = '<h3 class = "sse_h_notices_dispatch">' .
        		__('Message from the plugin "Giveaways for woocommerce" to the user %1$s(%2$s)', 'giveaways-for-woocommerce')
        		. '</h3>';
        $messag_headr = sprintf($messag_headr, $current_user_login, $current_user_roles_str);

        if ((int) $current_user_ID !== (int) $user_ID) {
        	$messag_content = __('You can not confirm this dispatch of coupon notifications, as it was initiated by the user <strong>%1$s</strong>.',
        	    'giveaways-for-woocommerce');
        	$messag_err = $messag_headr . '<p class = "sse_p_notices_dispatch">' . sprintf($messag_content, $user_login) . '</p>';
        	$coupon_sse->confirm_sending_emails_err('user', $messag_err, $user_ID, $coupon_id);
        	echo(json_encode('err_user_login'));
        	wp_die();
        }


          if ((int) $save_user_id !== (int) $user_ID) {
        	$messag_content = __('This mailing about coupons cannot be confirmed because it was re-stored by the user	<strong>%1$s</strong>.',
        	    'giveaways-for-woocommerce');
        	$messag_err = $messag_headr . '<p class = "sse_p_notices_dispatch">' . sprintf($messag_content, $user_login) . '</p>';
        	$coupon_sse->confirm_sending_emails_err('err', $messag_err, $user_ID, $coupon_id);
        	echo(json_encode('err_user_login'));
        	wp_die();
        }


        if (!empty($_SESSION['sse_coupon_id_' . $coupon_id])) {
        	$coupon_id = $_SESSION['sse_coupon_id_' . $coupon_id];

        	if($coupon_sse->get_notices_full_cleaning()){
        		$full_cleaning = true;
        		$cleaning = false;
        	}else{
        		switch ( $coupon_sse->get_notices_status_id() ) {
        		case 0:
        		case 2:
        			$full_cleaning = false;
        			$cleaning = false;
        			break;
        		case 3:
        		case 4:
        			$full_cleaning = false;
        			$cleaning = true;
        			break;
        		case 5:
        		case 6:
        		case 7:
        		case 100:
        			$full_cleaning = true;
        			$cleaning = false;
        			break;
        		default:
        			$full_cleaning = false;
        			$cleaning = false;
        		}
        	}

        	if($full_cleaning){
        		DCP_HOOK::del_coupon_notices( $coupon_id, true, true );

        		$post_notices_status = __( 'there is no notification', 'giveaways-for-woocommerce');
        		$post_notices_status_id = 0;

        		$coupon_sse->set_props(array(
        				'notices_status' 		=> $post_notices_status,
        				'notices_status_id' 		=> $post_notices_status_id ,
        			));

        		$coupon_sse->save();
        	}

        if ($notif_act == 'add'){
        	$post = get_post( $coupon_id );

           	if ($post->post_status != 'publish') {
        		$messag_content = __('This mailing about coupons cannot be confirmed, since this coupon was not published.',
        		    'giveaways-for-woocommerce');
        		$messag_err = $messag_headr . '<p class = "sse_p_notices_dispatch">' .  $messag_content . '</p>';
        		$coupon_sse->confirm_sending_emails_err('err', $messag_err, $user_ID, $coupon_id);
        		DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        		echo(json_encode('err_status_publish'));
        		wp_die();
        		}

        	if ($email_coupon_cron) {
        		$post_date_dispatch_email_u = ((int) $coupon_sse->get_date_dispatch_notices_u()->date('U')) - (current_time('timestamp') - time());

        		if ($post_date_dispatch_email_u >= time()) {

        			if(!$full_cleaning && $cleaning){
        				DCP_HOOK::del_coupon_notices( $coupon_id, $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)], $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] && $_SESSION['dcp_getCron_sse_'.strval($coupon_id)] );
        			}

        			wp_schedule_single_event(
        				$post_date_dispatch_email_u,
        				'dcp_cp_ntc_dispatch_sse',
        				array( $coupon_id )
        			);

        			$post_notices_status = __( 'Confirmed', 'giveaways-for-woocommerce');
        			$post_notices_status_id = 1;
        			$post_date_newsletter = $coupon_sse->get_date_dispatch_notices_u();

        			$coupon_sse->set_props(array(
        				'notices_status' 		=> $post_notices_status,
        				'notices_status_id' 		=> $post_notices_status_id ,
        				'date_newsletter' 		=> $post_date_newsletter ,
        			));

        			$coupon_sse->save();

        			DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        			$messag_dispatch_email = 'successfully';
        		} else {
        			DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        			$messag_content = __('The date and time set for the CRON is less than the current date and time, so the newsletter is canceled.',
        			    'giveaways-for-woocommerce');
        			$messag_err = $messag_headr . '<p class = "sse_p_notices_dispatch">' . $messag_content . '</p>';
        			$coupon_sse->confirm_sending_emails_err('err', $messag_err, $user_ID, $coupon_id);
        			$messag_dispatch_email = 'err_time';
        		}
        	} else {

        		if(!$full_cleaning  && $cleaning){
        			DCP_HOOK::del_coupon_notices( $coupon_id, $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)], $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] && $_SESSION['dcp_getCron_sse_'.strval($coupon_id)] );
        		}

        		do_action('dcp_cp_ntc_dispatch_sse',  $coupon_id);

        		$post_notices_status = __( 'Confirmed', 'giveaways-for-woocommerce');
        		$post_notices_status_id = 1;
        		$post_date_newsletter = time();

        		$coupon_sse->set_props(array(
        				'notices_status' 		=> $post_notices_status,
        				'notices_status_id' 		=> $post_notices_status_id ,
        				'date_newsletter' 		=> $post_date_newsletter ,
        			));

        		$coupon_sse->save();

        		DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        		$messag_dispatch_email = 'successfully';
        	}

        }

        if ($notif_act == 'del'){

        	if(!$full_cleaning && $cleaning){
        			DCP_HOOK::del_coupon_notices( $coupon_id, $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)], $_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] && $_SESSION['dcp_getCron_sse_'.strval($coupon_id)] );

        	  		$post_notices_status = __( 'there is no notification', 'giveaways-for-woocommerce');
        		$post_notices_status_id = 0;
        		$post_date_newsletter = time();

        		$coupon_sse->set_props(array(
        				'notices_status' 		=> $post_notices_status,
        				'notices_status_id' 		=> $post_notices_status_id ,
        				'date_newsletter' 		=> $post_date_newsletter ,
        			));

        		$coupon_sse->save();
        	  	}

        		DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        		$messag_dispatch_email = 'no_dispatch';
        	}

        } else {
        	DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        	$messag_content        = __('You cannot confirm this mailing about coupons, because the session in which it was initiated has already been completed.',
        	    'giveaways-for-woocommerce');
        	$messag_err            = $messag_headr . '<p class = "sse_p_notices_dispatch">' . $messag_content . '</p>';
        	$coupon_sse->confirm_sending_emails_err('err', $messag_err, $user_ID, $coupon_id);
        	$messag_dispatch_email = 'err_session';
        }

        echo(json_encode($messag_dispatch_email));
        wp_die();
    }

  /**
   * Undo notifications.
   */
    public static function no_notices_dispatch() {
        $nonce     = $_POST['nonce'];
        $coupon_id = isset($_POST['idCoupon']) ? wc_clean($_POST['idCoupon']): '';
        $user_ID   = isset($_POST['userID']) ? wc_clean($_POST['userID']): '';
        $notif_act   = isset($_POST['notifAct']) ? wc_clean($_POST['notifAct']): '';
        $err_status   = isset($_POST['errStatus']) ? wc_clean($_POST['errStatus']): '';

        // проверяем nonce код, если проверка не пройдена прерываем обработку
        if (!wp_verify_nonce($nonce, 'myajax-nonce'))
          die('Stop!');

        if ( $notif_act == 'del' || $notif_act == 'add' ){
        DCP_ADMIN_NOTICES::remove_notice('sse_coupon_' . (int) $user_ID . '_' . (int) $coupon_id);
        }

        if ( $notif_act == 'err' ){
        DCP_ADMIN_NOTICES::remove_notice('coupon_err_'  . $err_status . '_' . (int) $user_ID . '_' . (int) $coupon_id);
        }
        $messag_dispatch_email = 'no_dispatch';
        echo(json_encode($messag_dispatch_email));
        wp_die();
    }


  /**
   * Download previous notifications (client).
   */
    public static function notices_next() {
    	$nonce = $_POST['nonce'];

    	// check nonce code, if check fails interrupt processing
    	if (!wp_verify_nonce($nonce, 'myajax_nonce_user')){
    		die('Stop!');
    	}

    	echo(json_encode(DCP_HTML_CODE_NOTIF::account_new_coupons()));
    	wp_die();
    }

   /**
   * Delete current notifications (client).
   */
    public static function notices_del() {
    		$nonce = $_POST['nonce'];
    		$del_id = isset($_POST['id_coupon']) ? wc_clean($_POST['id_coupon']): '';

    		// check nonce code, if check fails interrupt processing
    		if (!wp_verify_nonce($nonce, 'myajax_nonce_user')) {
    			die('Stop!');
    		}


    		$current_user = wp_get_current_user();
    		$current_user_ID = $current_user->ID;

    		$user_id_coupon = esc_textarea(get_user_meta($current_user_ID, 'notices_new_coupon_id', true));

    		if ($user_id_coupon !== "") {
    			$pos = strripos($user_id_coupon, ',');
    			if ($pos) {
    				$user_id_coupon = str_replace("," . $del_id . ",", ",", "," . $user_id_coupon . ",");
    				$user_id_coupon = substr($user_id_coupon, 1, -1);
    			} else {
    				$user_id_coupon = str_replace($del_id, "", $user_id_coupon);
    			}
    		} else {
    			echo(json_encode('no_del'));
    			wp_die();
    		}

    		update_user_meta($current_user_ID, 'notices_new_coupon_id', $user_id_coupon);
    		DCP_CP_SESSION_SAVE::ntc_clear_counter_add(1);

    		echo(json_encode('del'));
    		wp_die();
    	}

   /**
    * Notification of notification information change (client).
    */
    public static function notices_new() {
    	$nonce = $_POST['nonce'];

    	// check nonce code, if check fails interrupt processing
    	if (!wp_verify_nonce($nonce, 'myajax_nonce_user')) {
    		die('Stop!');
    	}

    	$current_user = wp_get_current_user();
    	$user_id = $current_user->ID;

    	$user_new_operat_time = get_user_meta($user_id, 'dcp_ntc_new_operat_time_sse', true);
    	$user_new_operat_name = get_user_meta($user_id, 'dcp_ntc_new_operat_name_sse', true);
    	$user_session_time=$_SESSION['dcp_ntc_start_time_sse'];

    	if( $user_new_operat_time >= $user_session_time ){
    		switch ($user_new_operat_name) {
    				case "add_coupon":
    					DCP_CP_SESSION_SAVE::ntc_start_time();
        				echo(json_encode(__('Your information about coupon  has been updated, please refresh the page for correct output (F5)',
        				'giveaways-for-woocommerce')));
        				break;
        			case "del_coupon":
    					DCP_CP_SESSION_SAVE::ntc_start_time();
        				echo(json_encode(__('Your information about coupon  has been updated, please refresh the page for correct output (F5)',
        				'giveaways-for-woocommerce')));
        				break;
    		}
    	}else{
    		echo(json_encode( "" ));
    	}
    	wp_die();
    }

   /**
    * Delete all messages to the administrator from the plugin.
    */
    public static function all_del_admin_notif_dcp(){
    	$nonce = $_POST['nonce'];

    	if (!wp_verify_nonce($nonce, 'myajax-nonce')){
    		die('Stop!');
    	}

    	DCP_ADMIN_NOTICES::remove_all_notices();

    	echo(json_encode('del_all'));
    	wp_die();

    }

}
DCP_AJAX::init();