<?php
/**
 * Messages to the administrator
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */

if (!defined('ABSPATH')) {
  exit;
}

class DCP_ENDPOINTS {

    /**
    * Hook in ajax handlers.
    */
    public static function init () {
        add_filter('query_vars', array(__CLASS__, 'add_query_vars'), 0);
        add_filter('the_title',  array(__CLASS__, 'endpoint_title'));
        add_filter('woocommerce_account_menu_items', array(__CLASS__, 'navigation_account_items'));
        add_action('woocommerce_account_sse-new-coupon_endpoint', array(__CLASS__, 'account_new_coupons'));
    }

    /**
     * Add new query var.
     * @param array $vars
     * @return array
     */
    public static function add_query_vars($vars) {
    	$vars[] = 'sse-new-coupon';
    	return $vars;
    }

    /**
     * Set endpoint title.
     * @param string $title
     * @return string
     */
    public static function endpoint_title($title) {
    	global $wp_query;

    	$is_endpoint = isset($wp_query->query_vars['sse-new-coupon']);
    	if ($is_endpoint && !is_admin() && is_main_query() && in_the_loop() && is_account_page()) {
    		// New page title.
    		$title = __('Notifications about coupons', 'giveaways-for-woocommerce');
    		remove_filter('the_title', 'sse_endpoint_title');
    	}

    	return $title;
    }

    /**
     * Adding the menu item "New coupon" on the page "My account"
     * @param array $items
     * @return array
     */
    public static function navigation_account_items($items) {
    	// Remove the logout menu item.
    	$logout = $items['customer-logout'];
    	unset($items['customer-logout']);
    	// Insert your custom endpoint.
    	$items['sse-new-coupon'] = __('Notifications about coupons', 'giveaways-for-woocommerce');
    	// Insert back the logout item.
    	$items['customer-logout'] = $logout;

    	return $items;
    }

    /**
     * Formation of HTML code of notifications
     */
	public static function account_new_coupons() {
		DCP_CP_SESSION_SAVE::ntc_start_time();
		echo DCP_HTML_CODE_NOTIF::account_new_coupons(FALSE);
		}

}
DCP_ENDPOINTS::init();