<?php
/**
 * Function
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */

if (!defined('ABSPATH')) {
  exit;
}

class DCP_FUNCTIONS {

  /**
   * If the variable $coupon_emails is empty, it stores all the users email with the customer role.
   */
  public static function coupon_emails_all($coupon_emails) {
    if (empty($coupon_emails)) {
      $users         = get_users(array(
        'role'   => 'customer',
        'fields' => array('user_email'),
      ));
      $coupon_emails = wp_list_pluck($users, 'user_email');
    }

    if ( is_array($coupon_emails)) {
    	$coupon_emails_arr = $coupon_emails;
    }else{
	$coupon_emails_arr = explode(',', $coupon_emails);
    }


    return $coupon_emails_arr;
  }

    /**
     * Function for displaying categories of list view.
     */
    public static function dcp_select_categor( $field ) {
    	global $thepostid, $post;

    	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    	$field['class']         = isset( $field['class'] ) ? $field['class'] : 'select short';
    	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
    	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
    	$field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;
    	$field['hide_empty']	= isset( $field['hide_empty'] ) ? $field['hide_empty'] : 1;
    	$field['multiple_size']	= isset( $field['multiple_size'] ) ? $field['multiple_size'] : 5;


    	// Custom attribute handling
    	$custom_attributes = array();

    	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

    		foreach ( $field['custom_attributes'] as $attribute => $value ) {
    			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
    		}
    	}

    	echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '">
    		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

    	if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
    		echo wc_help_tip( $field['description'] );
    	}


    	$args = array(
    		'echo' => 0,
        		'taxonomy' => 'product_cat',
        		'hierarchical'=> 1,
        		'value_field' => 'slug',
        		'name' =>  esc_attr( $field['name'] ),
        		'id' =>  esc_attr( $field['id'] ),
        		'class' => esc_attr( $field['class'] ),
        		'show_option_none' => '---',
        		'hide_empty' => esc_attr( $field['hide_empty'] ),
    	);
    	 $txt_sel = wp_dropdown_categories($args);
    	 if ( isset( $field['multiple'] ) && 0 == $field['multiple']) {
    	 	$txt_sel = str_replace('select', 'select size="'.esc_attr( $field['multiple_size'] ).'" multiple', $txt_sel);
    	}
    	echo $txt_sel;

    	if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
    		echo '<span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
    	}
    echo '</p>';
    }

    /**
     * Function for displaying categories in the form of a drop-down list and
     * products of the selected category in the form of a list.
     */
    public static function dcp_select_categor_products( $field ) {
    	global $thepostid, $post;

    	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    	$field['ct_class']         = isset( $field['ct_class'] ) ? $field['ct_class'] : 'select short';
    	$field['ct_style']         = isset( $field['ct_style'] ) ? $field['ct_style'] : '';
    	$field['ct_wrapper_class'] = isset( $field['ct_wrapper_class'] ) ? $field['ct_wrapper_class'] : '';
    	$field['ct_value']         = isset( $field['ct_value'] ) ? $field['ct_value'] : get_post_meta( $thepostid, $field['ct_id'], true );
    	$field['ct_name']          = isset( $field['ct_name'] ) ? $field['ct_name'] : $field['ct_id'];
    	$field['ct_desc_tip']      = isset( $field['ct_desc_tip'] ) ? $field['ct_desc_tip'] : false;
    	$field['ct_hide_empty']		= isset( $field['ct_hide_empty'] ) ? $field['ct_hide_empty'] : 1;
    	$field['ct_multiple_size']	= isset( $field['ct_multiple_size'] ) ? $field['ct_multiple_size'] : 5;

    	$field['prd_class']         = isset( $field['prd_class'] ) ? $field['prd_class'] : 'select short';
    	$field['prd_style']         = isset( $field['prd_style'] ) ? $field['prd_style'] : '';
    	$field['prd_wrapper_class'] = isset( $field['prd_wrapper_class'] ) ? $field['prd_wrapper_class'] : '';
    	$field['prd_value']         = isset( $field['prd_value'] ) ? $field['prd_value'] : get_post_meta( $thepostid, $field['prd_id'], true );
    	$field['prd_name']          = isset( $field['prd_name'] ) ? $field['prd_name'] : $field['prd_id'];
    	$field['prd_desc_tip']      = isset( $field['prd_desc_tip'] ) ? $field['prd_desc_tip'] : false;
    	$field['prd_hide_empty']	= isset( $field['prd_hide_empty'] ) ? $field['prd_hide_empty'] : 1;
    	$field['prd_multiple_size']	= isset( $field['prd_multiple_size'] ) ? $field['prd_multiple_size'] : 5;


    	// Custom attribute handling categor
    	$ct_custom_attributes = array();

    	if ( ! empty( $field['ct_custom_attributes'] ) && is_array( $field['ct_custom_attributes'] ) ) {

    		foreach ( $field['ct_custom_attributes'] as $ct_attribute => $ct_value ) {
    			$ct_custom_attributes[] = esc_attr( $ct_attribute ) . '="' . esc_attr( $ct_value ) . '"';
    		}
    	}

    	echo '<p class="form-field ' . esc_attr( $field['ct_id'] ) . '_field ' . esc_attr( $field['ct_wrapper_class'] ) . '">
    		<label for="' . esc_attr( $field['ct_id'] ) . '">' . wp_kses_post( $field['ct_label'] ) . '</label>';

    	if ( ! empty( $field['ct_description'] ) && false !== $field['ct_desc_tip'] ) {
    		echo wc_help_tip( $field['ct_description'] );
    	}


    	$args = array(
    		'echo' => 0,
        		'taxonomy' => 'product_cat',
        		'hierarchical'=> 1,
        		'value_field' => 'slug',
        		'name' =>  esc_attr( $field['ct_name'] ),
        		'id' =>  esc_attr( $field['ct_id'] ),
        		'class' => esc_attr( $field['ct_class'] ),
        		'show_option_none' => '---',
        		'hide_empty' => esc_attr( $field['ct_hide_empty'] ),
    	);
    	 $txt_sel = wp_dropdown_categories($args);
    	 if ( isset( $field['ct_multiple'] ) && 0 == $field['ct_multiple']) {
    	 	$txt_sel = str_replace('select', 'select size="'.esc_attr( $field['ct_multiple_size'] ).'" multiple', $txt_sel);
    	}
    	echo $txt_sel;


    	// Custom attribute handling products
    	$prd_custom_attributes = array();

    	if ( ! empty( $field['prd_custom_attributes'] ) && is_array( $field['prd_custom_attributes'] ) ) {

    		foreach ( $field['prd_custom_attributes'] as $prd_attribute => $ct_value ) {
    			$prd_custom_attributes[] = esc_attr( $prd_attribute ) . '="' . esc_attr( $prd_value ) . '"';
    		}
    	}

    	$txt_size ='';
     	if ( isset( $field['prd_multiple'] ) && 0 == $field['prd_multiple']) {
    	 	$txt_size = 'size="'.esc_attr( $field['prd_multiple_size'] ).'" multiple ';
    	}

    	// Get shirts.
    		$args = array(
        			'orderby' => 'name',
        			'order' => 'ASC',
        			'limit' => -1,
    		);
    		$products = wc_get_products( $args );

    		$filterProd = '';

    		foreach ( $products as $product ) {
    			$filterProd =  $filterProd . '<option value="' . esc_attr( $product->get_id() )  . '">' . esc_html( $product->get_name() ) . '</option>';
    		}

        echo '<p class="form-field form-row form-row-full qualifier">';
        	echo '<label for="' . esc_attr( $field['prd_id'] ) . '">' . esc_attr( $field['prd_label'] ) . '</label>';
        echo '<select '.$txt_size. 'name="' . esc_attr( $field['prd_name'] ) . '" id="' . esc_attr( $field['prd_id'] ) .
            '" class="' . esc_attr( $field['prd_class'] ) . '" style="' . esc_attr( $field['prd_style'] ) . '" ' . implode( ' ', $prd_custom_attributes ) . '>';
        	echo $filterProd;
        echo '</select>';
        echo '</p>';

        echo '</p>';
    }

    /**
     * Function for displaying a text field with a button.
     */
    public static  function dcp_text_button_input( $field ) {
    	global $thepostid, $post;

    	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    	$field['placeholder']   = isset( $field['placeholder'] ) ? $field['placeholder'] : '';
    	$field['class']         = isset( $field['class'] ) ? $field['class'] : 'short';
    	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
    	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
    	$field['type']          = isset( $field['type'] ) ? $field['type'] : 'text';
    	$field['desc_tip']      = isset( $field['desc_tip'] ) ? $field['desc_tip'] : false;
    	$data_type              = empty( $field['data_type'] ) ? '' : $field['data_type'];
    	$field['class_button']         = isset( $field['class_button'] ) ? $field['class_button'] : 'button button-primary';
    	$field['title_button']         = isset( $field['title_button'] ) ? $field['title_button'] : '';
    	$field['style_button']         = isset( $field['style_button'] ) ? $field['style_button'] : '';
    	$field['type_button']          = isset( $field['type_button'] ) ? $field['type_button'] : 'button';
    	$field['text_button']          = isset( $field['text_button'] ) ? $field['text_button'] : 'Button';

    	switch ( $data_type ) {
    		case 'price' :
    			$field['class'] .= ' wc_input_price';
    			$field['value']  = wc_format_localized_price( $field['value'] );
    			break;
    		case 'decimal' :
    			$field['class'] .= ' wc_input_decimal';
    			$field['value']  = wc_format_localized_decimal( $field['value'] );
    			break;
    		case 'stock' :
    			$field['class'] .= ' wc_input_stock';
    			$field['value']  = wc_stock_amount( $field['value'] );
    			break;
    		case 'url' :
    			$field['class'] .= ' wc_input_url';
    			$field['value']  = esc_url( $field['value'] );
    			break;

    		default :
    			break;
    	}

    	// Custom attribute handling
    	$custom_attributes = array();

    	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

    		foreach ( $field['custom_attributes'] as $attribute => $value ) {
    			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
    		}
    	}

    	echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '">
    		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';

    	if ( ! empty( $field['description'] ) && false !== $field['desc_tip'] ) {
    		echo wc_help_tip( $field['description'] );
    	}

    	echo '<input type="' . esc_attr( $field['type'] ) . '" class="' . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" name="' . esc_attr( $field['name'] ) . '" id="' . esc_attr( $field['id'] ) . '" value="' . esc_attr( $field['value'] ) . '" placeholder="' . esc_attr( $field['placeholder'] ) . '" ' . implode( ' ', $custom_attributes ) . ' /> ';

    	echo '<button type="' . esc_attr( $field['type_button'] ) . '" id="' . esc_attr( $field['id_button'] ) . '" class="' . esc_attr( $field['class_button'] ) . '" title="' . esc_attr( $field['title_button'] ) . '" style="' . esc_attr( $field['style_button'] ) . '">'. esc_attr( $field['text_button'] ) .'</button>';

    	if ( ! empty( $field['description'] ) && false === $field['desc_tip'] ) {
    		echo '<span class="description">' . wp_kses_post( $field['description'] ) . '</span>';
    	}

    	echo '</p>';
    }

    /**
     * Function for displaying the list of email users.
     */
    public static function dcp_select_emails( $field ) {
    	global $thepostid, $post;

    	$thepostid              = empty( $thepostid ) ? $post->ID : $thepostid;
    	$field['class']         = isset( $field['class'] ) ? $field['class'] : 'select short';
    	$field['style']         = isset( $field['style'] ) ? $field['style'] : '';
    	$field['wrapper_class'] = isset( $field['wrapper_class'] ) ? $field['wrapper_class'] : '';
    	$field['value']         = isset( $field['value'] ) ? $field['value'] : get_post_meta( $thepostid, $field['id'], true );
    	$field['name']          = isset( $field['name'] ) ? $field['name'] : $field['id'];
    	$field['hide_empty']	= isset( $field['hide_empty'] ) ? $field['hide_empty'] : 1;
    	$field['multiple_size']	= isset( $field['multiple_size'] ) ? $field['multiple_size'] : 5;



    	// Custom attribute handling
    	$custom_attributes = array();

    	if ( ! empty( $field['custom_attributes'] ) && is_array( $field['custom_attributes'] ) ) {

    		foreach ( $field['custom_attributes'] as $attribute => $value ) {
    			$custom_attributes[] = esc_attr( $attribute ) . '="' . esc_attr( $value ) . '"';
    		}
    	}

    	echo '<p class="form-field ' . esc_attr( $field['id'] ) . '_field ' . esc_attr( $field['wrapper_class'] ) . '">
    		<label for="' . esc_attr( $field['id'] ) . '">' . wp_kses_post( $field['label'] ) . '</label>';



     	if ( isset( $field['multiple'] ) && 0 == $field['multiple']) {
    	 	$txt_multiple = 'size="'.esc_attr( $field['multiple_size'] ).'" multiple ';
    	}else{
    		$txt_multiple = '';
    	}

    	$users = get_users(array(
            	'fields' => array('ID', 'user_email'),
            	'orderby'      => 'user_email',
    		'order'        => 'ASC',
          	));

          	foreach ( $users as $user ) {
          		$options[$user->ID] = $user->user_email;
          	}

    	echo '<select '. $txt_multiple .'"id="' . esc_attr( $field['id'] ) . '" name="' . esc_attr( $field['name'] ) . '" class="'
    	    . esc_attr( $field['class'] ) . '" style="' . esc_attr( $field['style'] ) . '" ' . implode( ' ', $custom_attributes ) . '>';

    	foreach ( $options as $key => $value ) {
    		echo '<option value="' . esc_attr( $key ) . '" ' . selected( esc_attr( $field['value'] ), esc_attr( $key ), false ) . '>' . esc_html( $value ) . '</option>';
    	}

    	echo '</select> ';
    echo '</p>';
    }

     /**
     * The function of checking the correctness of the list ID.
     */
    public static function dcp_validate_listID( $listID ) {
    	if(empty($listID) || !is_string($listID)){
    		return '';
    	}
    	if (preg_match('/[^0-9,]$/', $listID)){
    		return '0';
    	}else{
    		return $listID;
    	}
    }

}
