<?php
/**
 * Meta coupon data.
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class DCP_CP_NTC_DATA_STORE_CPT extends WC_Data_Store_WP {

	/**
	 * Internal meta type used to store coupon data.
	 *
	 * @var string
	 */
	protected $meta_type = 'post';

	/**
	 * Data stored in meta keys, but not considered "meta" for a coupon.
	 *
	 * @var array
	 */
	protected $internal_meta_keys = array(
		'dcp_notices_coupon_sse',
		'dcp_notices_coupon_cron_sse',
		'dcp_date_dispatch_notices_sse',
		'dcp_date_dispatch_notices_u_sse',
		'dcp_editor_notices_sse',
		'dcp_list_emails_n_sse',
        	'dcp_notices_status_sse',
        	'dcp_notices_status_id_sse',
        	'dcp_save_user_id_sse',
        	'dcp_notices_full_cleaning_sse',
        	'dcp_date_newsletter_sse',
	);

	/**
	 * Method to read a coupon.
	 *
	 * @param WC_Coupon
	 */
	public function read( &$coupon ) {
		$coupon->set_defaults();

		if ( ! $coupon->get_id() || ! ( $post_object = get_post( $coupon->get_id() ) ) || 'shop_coupon' !== $post_object->post_type ) {
			throw new Exception( __( 'Invalid coupon.', 'giveaways-for-woocommerce' ) );
		}

		$coupon_id = $coupon->get_id();
		$coupon->set_props( array(
			'notices_coupon'             	=> 'yes' === get_post_meta( $coupon_id, 'dcp_notices_coupon_sse', true ),
			'notices_coupon_cron'        	=> 'yes' === get_post_meta( $coupon_id, 'dcp_notices_coupon_cron_sse', true ),
			'date_dispatch_notices'		=> get_post_meta( $coupon_id, 'dcp_date_dispatch_notices_sse', true),
			'date_dispatch_notices_u'	=> get_post_meta( $coupon_id, 'dcp_date_dispatch_notices_u_sse', true),
			'editor_notices'         	=> get_post_meta( $coupon_id, 'dcp_editor_notices_sse', true ),
			'list_emails_n'			=> get_post_meta( $coupon_id, 'dcp_list_emails_n_sse', true ),
			'notices_status'		=> get_post_meta( $coupon_id, 'dcp_notices_status_sse', true),
			'notices_status_id'         	=> get_post_meta( $coupon_id, 'dcp_notices_status_id_sse', true ),
			'save_user_id'			=> get_post_meta( $coupon_id, 'dcp_save_user_id_sse', true ),
			'notices_full_cleaning'		=> 'yes' === get_post_meta( $coupon_id, 'dcp_notices_full_cleaning_sse', true ),
			'date_newsletter'		=> get_post_meta( $coupon_id, 'dcp_date_newsletter_sse', true),
		) );
		$coupon->read_meta_data();
		$coupon->set_object_read( true );
                do_action( 'dcp_cp_ntc_loaded_sse', $coupon );


	}

	/**
	 * Updates a coupon in the database.
	 *
	 * @param WC_Coupon
	 */
	public function update( &$coupon ) {
		$coupon->save_meta_data();
		$changes = $coupon->get_changes();

		$updated_props     = array();
		$meta_key_to_props = array(
			'dcp_notices_coupon_sse'           	=> 'notices_coupon',
			'dcp_notices_coupon_cron_sse'           => 'notices_coupon_cron',
			'dcp_date_dispatch_notices_sse'     	=> 'date_dispatch_notices',
			'dcp_date_dispatch_notices_u_sse'     	=> 'date_dispatch_notices_u',
			'dcp_editor_notices_sse'		=> 'editor_notices',
			'dcp_list_emails_n_sse'			=> 'list_emails_n',
			'dcp_notices_status_sse' 		=> 'notices_status',
        		'dcp_notices_status_id_sse' 		=> 'notices_status_id',
        		'dcp_save_user_id_sse'			=> 'save_user_id',
        		'dcp_notices_full_cleaning_sse'		=> 'notices_full_cleaning',
        		'dcp_date_newsletter_sse'		=> 'date_newsletter',
		);

		$props_to_update = $this->get_props_to_update( $coupon, $meta_key_to_props );
		foreach ( $props_to_update as $meta_key => $prop ) {
			$value = $coupon->{"get_$prop"}( 'edit' );
			switch ( $prop ) {
				case 'notices_coupon' :
				case 'notices_coupon_cron' :
				case 'notices_full_cleaning' :
					$updated = update_post_meta( $coupon->get_id(), $meta_key, wc_bool_to_string( $value ) );
					break;
				case 'date_dispatch_notices_u' :
				case 'date_newsletter' :
					$updated = update_post_meta( $coupon->get_id(), $meta_key, ( $value ? $value->getTimestamp() : null ) );
					break;
				case 'date_dispatch_notices' :
				case 'editor_notices' :
				case 'list_emails_n' :
				case 'notices_status' :
				case 'notices_status_id' :
				case 'save_user_id' :
					$updated = update_post_meta( $coupon->get_id(), $meta_key, $value );
					break;
			}
			if ( $updated ) {
				$updated_props[] = $prop;
			}
		}

		$coupon->apply_changes();
	}

}