<?php
/**
 * Add methods and properties to work with coupon metadata.
 *
 * @package  Giveaways for woocommerce/Classes
 * @author   Sindyakin Sergei
 * @version 1.0.0
 */

if (!defined('ABSPATH')) {
    exit;
}

include_once(WC()->plugin_path() . '/includes/legacy/class-wc-legacy-coupon.php' );

class DCP_CP_NTC extends WC_Legacy_Coupon {

    /**
	 * Strings to find in subjects/headings.
	 * @var array
	 */
	public $find = array();

	/**
	 * Strings to replace in subjects/headings.
	 * @var array
	 */
	public $replace = array();

    /**
     * Data array, with defaults.
     *
     * @var array
     */
    protected $data = array(
        'notices_coupon' 		=> false,
        'notices_coupon_cron' 		=> false,
        'date_dispatch_notices' 	=> null,
        'date_dispatch_notices_u' 	=> null,
        'editor_notices' 		=> null,
        'list_emails_n'			=> null,
        'notices_status' 		=> null,
        'notices_status_id' 		=> null,
        'save_user_id'			=> null,
        'notices_full_cleaning'		=> false,
        'date_newsletter'       	=> null,
    );

    // Coupon message codes
    const E_WC_COUPON_INVALID_FILTERED = 100;
    const E_WC_COUPON_EXPIRED = 107;

    /**
     * Cache group.
     * @var string
     */
    protected $cache_group = 'coupons';

    /**
     * Coupon constructor. Loads coupon data.
     * @param mixed $data Coupon data, object, ID or code.
     */
    public function __construct($data = '') {
        parent::__construct($data);

        if ($data instanceof WC_Coupon) {
            $this->set_id(absint($data->get_id()));
        } elseif (is_numeric($data) && 'shop_coupon' === get_post_type($data)) {
            $this->set_id($data);
        } elseif (!empty($data)) {
            $this->set_id(wc_get_coupon_id_by_code($data));
            $this->set_code($data);
        } else {
            $this->set_object_read(true);
        }

        $this->data_store = new DCP_CP_NTC_DATA_STORE_CPT();
        if ($this->get_id() > 0) {
            $this->data_store->read($this);
        }

        // Find/replace
        $this->find['blogname'] = '{blogname}';
        $this->find['site-title'] = '{site_title}';
        $this->replace['blogname'] = $this->get_blogname();
        $this->replace['site-title'] = $this->get_blogname();
    }

    /*
      |--------------------------------------------------------------------------
      | Getters
      |--------------------------------------------------------------------------
      |
      | Methods for getting data from the coupon object.
      |
     */

     /**
     * Get notices_coupon.
     *
     * @param  string $context
     * @return bool
     */
    public function get_notices_coupon($context = 'view') {
        return $this->get_prop('notices_coupon', $context);
    }

    /**
     * Get notices_coupon_cron.
     *
     * @param  string $context
     * @return bool
     */
    public function get_notices_coupon_cron($context = 'view') {
        return $this->get_prop('notices_coupon_cron', $context);
    }

   /**
     * Get date_dispatch_notices
     *
     * @param  string $context
     * @return WC_DateTime|NULL object if the date is set or null if there is no date.
     */
    public function get_date_dispatch_notices($context = 'view') {
        return $this->get_prop('date_dispatch_notices', $context);
    }

    /**
     * Get date_dispatch_notices_u
     *
     * @param  string $context
     * @return WC_DateTime|NULL object if the date is set or null if there is no date.
     */
    public function get_date_dispatch_notices_u($context = 'view') {
        return $this->get_prop('date_dispatch_notices_u', $context);
    }

    /**
     * Get editor_notices.
     *
     * @param  string $context
     * @return string.
     */
    public function get_editor_notices($context = 'view') {
        return $this->get_prop('editor_notices', $context);
    }

    /**
     * Get WordPress blog name.
     *
     * @return string
     */
    public function get_blogname() {
        return wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);
    }

	/**
     * Get list_emails_n.
     *
     * @param  string $context
     * @return string.
     */
    public function get_list_emails_n($context = 'view') {
        return $this->get_prop('list_emails_n', $context);
    }

    /**
     * Get notices_status.
     *
     * @param  string $context
     * @return string.
     */
    public function get_notices_status($context = 'view') {
        return $this->get_prop('notices_status', $context);
    }

   /**
     * Get notices_status_id.
     *
     * @param  string $context
     * @return integer.
     */
    public function get_notices_status_id($context = 'view') {
        return $this->get_prop('notices_status_id', $context);
    }

    /**
     * Get save_user_id.
     *
     * @param  string $context
     * @return integer.
     */
    public function get_save_user_id($context = 'view') {
        return $this->get_prop('save_user_id', $context);
    }

    /**
     * Get notices full cleaning.
     *
     * @param  string $context
     * @return bool
     */
    public function get_notices_full_cleaning($context = 'view') {
        return $this->get_prop('notices_full_cleaning', $context);
    }

     /**
     * Get date_newsletter
     *
     * @param  string $context
     * @return WC_DateTime|NULL object if the date is set or null if there is no date.
     */
    public function get_date_newsletter($context = 'view') {
        return $this->get_prop('date_newsletter', $context);
    }
    /*
      |--------------------------------------------------------------------------
      | Setters
      |--------------------------------------------------------------------------
      |
      | Functions for setting coupon data. These should not update anything in the
      | database itself and should only change what is stored in the class
      | object.
      |
     */

	/**
     * Set notices_coupon.
     *
     * @param  bool $email_coupon
     */
    public function set_notices_coupon($notices_coupon) {
        $this->set_prop('notices_coupon', (bool) $notices_coupon);
    }

    /**
     * Set notices_coupon_cron.
     *
     * @param  bool $email_coupon
     */
    public function set_notices_coupon_cron($notices_coupon_cron) {
        $this->set_prop('notices_coupon_cron', (bool) $notices_coupon_cron);
    }

    /**
     * Set expiration date.
     *
     * @param string|integer|null $date UTC timestamp, or ISO 8601 DateTime. If the DateTime string has no timezone or offset, WordPress site timezone will be assumed. Null if there is no date.
     */
    public function set_date_dispatch_notices($date) {
        $this->set_prop('date_dispatch_notices', $date);
    }

    /**
     * Set editor notices.
     *
     * @param  bool $email_coupon
     */
    public function set_editor_notices($editor_notices) {
        $this->set_prop('editor_notices', $editor_notices);
    }

    /**
     * Set expiration date.
     *
     * @param string|integer|null $date UTC timestamp, or ISO 8601 DateTime. If the DateTime string has no timezone or offset, WordPress site timezone will be assumed. Null if there is no date.
     */
    public function set_date_dispatch_notices_u($date) {
        $this->set_date_prop('date_dispatch_notices_u', $date);
    }

    /**
     * Set list_emails_n
     *
     * @param string $list_emails_n
     */
    public function set_list_emails_n($list_emails_n) {
        $this->set_prop('list_emails_n', $list_emails_n);
    }

     /**
     * Set notices_status
     *
     * @param  string $notices_status
     */
    public function set_notices_status($notices_status) {
        $this->set_prop('notices_status', $notices_status);
    }

    /**
     * Set notices_status_id
     *
     * @param  integer  $notices_status_id
     */
    public function set_notices_status_id($notices_status_id) {
        $this->set_prop('notices_status_id', $notices_status_id );
    }

    /**
     * Set save_user_id
     *
     * @param  integer $save_user_id
     */
    public function set_save_user_id($save_user_id) {
        $this->set_prop('save_user_id', $save_user_id);
    }


    /**
     * Set notices_full_cleaning.
     *
     * @param  bool $notices_full_cleaning
     */
    public function set_notices_full_cleaning($notices_full_cleaning) {
        $this->set_prop( 'notices_full_cleaning', (bool) $notices_full_cleaning );
    }

     /**
     * Set expiration date.
     *
     * @param string|integer|null $date UTC timestamp, or ISO 8601 DateTime. If the DateTime string has no timezone or offset, WordPress site timezone will be assumed. Null if there is no date.
     */
    public function set_date_newsletter($date) {
        $this->set_date_prop('date_newsletter', $date);
    }

    /*
      |--------------------------------------------------------------------------
      | Validation & Error Handling
      |--------------------------------------------------------------------------
     */

    /**
     * Returns the error_message string.
     *
     * @return string
     */
    public function get_error_message() {
        return $this->error_message;
    }

    /**
     * Ensure coupon date is valid or throw exception.
     */
    private function validate_date_dispatch_notices() {
        if ($this->get_date_dispatch_notices() && current_time('timestamp', true) > $this->get_date_dispatch_notices()->getTimestamp()) {
            throw new Exception($error_code = self::E_WC_COUPON_EXPIRED);
        }
    }

    /**
     * Check if a coupon is valid.
     *
     * @return boolean validity
     */
    public function is_valid() {
        try {
            $this->validate_date_dispatch_notices();

            if (!apply_filters('dcp_cp_ntc_is_valid_sse', true, $this)) {
                throw new Exception(self::E_WC_COUPON_INVALID_FILTERED);
            }
        } catch (Exception $e) {
            $this->error_message = $this->get_coupon_error($e->getMessage());
            return false;
        }

        return true;
    }

    /**
     * Converts one of the DCP_COUPON message/error codes to a message string and.
     * displays the message/error.
     *
     * @param int $msg_code Message/error code.
     */
    public function add_coupon_message($msg_code) {
        $msg = $this->get_coupon_error($msg_code);

        if (!$msg) {
            return;
        }

        wc_add_notice($msg, 'error');
    }

    /**
	 * Format email string.
	 *
	 * @param mixed $string
	 * @return string
	 */
	public function format_string( $string ) {
		return str_replace( apply_filters( 'dcp_cp_ntc_format_string_find_sse', $this->find, $this ), apply_filters( 'dcp_cp_ntc_format_string_replace_sse', $this->replace, $this ), $string );
	}

    /**
	 * Generates confirmation messages sent/cleared of coupon notifications for the administrator.
	 *
	 * @param integer $coupon_id
	 * @param bool $notices_coupon
	 * @return string
	 */
    public function confirm_sending_notices($coupon_id, $notices_coupon) {
        $time_next_scheduled = 0;

        $notices_coupon = (bool) $notices_coupon;

        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;
        $user_login = $current_user->user_login;
        $user_roles = $current_user->roles;
        $user_roles_str = implode(',', $user_roles);

        $coupon_sse = new DCP_CP_NTC($coupon_id);
        $notices_coupon_cron = $coupon_sse->get_notices_coupon_cron();
        $coupon_emails = $coupon_sse->get_list_emails_n();


        $coupon = new WC_Coupon($coupon_id);
        $coupon_code = $coupon->get_code();

        $head = '<h3 class = "sse_h_notices_dispatch">Message from the plugin "Giveaways for woocommerce" the user %1$s(%2$s)</h3>';

        if( $notices_coupon_cron){
            if(is_null ($coupon_sse->get_date_dispatch_notices_u())){
                $date_cron = 0;
            }else{
                $date_cron=(int) $coupon_sse->get_date_dispatch_notices_u()->date('U');
            }

            if($date_cron == 0){
                $content = __(
                    'You forgot to specify the date of mailing notifications about coupon  <strong>"%3$s"</strong> for the task CRON.',
                    'giveaways-for-woocommerce');
                $messag_err = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code);
            	$coupon_sse->confirm_sending_emails_err('user', $messag_err, $user_id, $coupon_id);

                return;
            }
        }

    	if($_SESSION['dcp_cp_ntc_old_sse_'.strval($coupon_id)] == true && $_SESSION['dcp_cp_ntc_cron_old_sse_'.strval($coupon_id)] == true ){
    	    	$_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] = true;
        		$_SESSION['dcp_getCron_sse_'.strval($coupon_id)] = true;
    	}elseif($_SESSION['dcp_cp_ntc_old_sse_'.strval($coupon_id)] == true && $_SESSION['dcp_cp_ntc_cron_old_sse_'.strval($coupon_id)] == false ){
    		$_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] = true;
        		$_SESSION['dcp_getCron_sse_'.strval($coupon_id)] = false;
    	}else{
    		$_SESSION['dcp_getNotices_sse_'.strval($coupon_id)] = false;
        		$_SESSION['dcp_getCron_sse_'.strval($coupon_id)] = false;
    	}


        (bool) $notices_coupon_old = $_SESSION['dcp_cp_ntc_old_sse_'.strval($coupon_id)];
        (bool) $notices_coupon_cron_old = $_SESSION['dcp_cp_ntc_cron_old_sse_'.strval($coupon_id)];

        if ($notices_coupon_cron_old) {
        	 $time_next_scheduled = wp_next_scheduled(
    		'dcp_cp_ntc_dispatch_sse',
    		array( $coupon_id )
    		);
    	}

        unset($_SESSION['dcp_cp_ntc_old_sse_'.strval($coupon_id)]);

       $notices_status_id = $coupon_sse->get_notices_status_id();

        if ($notices_status_id == 2 || $notices_status_id == 7) {
    		$p1= $this->add_notices($coupon_id, $notices_status_id, $notices_coupon_cron, $coupon_emails, $coupon_code);

            $a1 = __('YES', 'giveaways-for-woocommerce');
            $a2 = __('NO', 'giveaways-for-woocommerce');

            DCP_ADMIN_NOTICES::add_custom_notice(
    			'sse_coupon_' . (int) $user_id . '_' . (int) $coupon_id,
    			 $p1 . '<p class="submit">'
    				. '<button class="button-primary sse_ok_notices_dispatch" data-id-coupon="'. (int) $coupon_id
    					. '" data-user-id="' . (int) $user_id . '">' . $a1 . '</button>'
    				. ' <button class="button-secondary sse_no_notices_dispatch" data-id-coupon="'. (int) $coupon_id
    					. '" data-user-id="' . (int) $user_id . '">' . $a2 . '</button>'
    				. '</p>'
            );
        } elseif ($notices_status_id == 4 || $notices_status_id == 6) {
    	$p1= $this->remove_notices($coupon_id, $notices_status_id, $coupon_code);

    	$a1 = __( 'YES', 'giveaways-for-woocommerce');
            $a2 = __('NO', 'giveaways-for-woocommerce');

            DCP_ADMIN_NOTICES::add_custom_notice(
    			'sse_coupon_' . (int) $user_id . '_' . (int) $coupon_id,
    			 $p1 . '<button class="button-primary sse_ok_notices_del" data-id-coupon="'. (int) $coupon_id
    			. '" data-user-id="' . (int) $user_id . '">' . $a1 . '</button>'
    			. ' <button class="button-secondary sse_no_notices_del" data-id-coupon="'. (int) $coupon_id
    			. '" data-user-id="' . (int) $user_id . '">' . $a2 . '</button>'
    			. '</p>'

    		);
        } elseif ($notices_status_id == 3 || $notices_status_id == 5) {
    		$p1= $this->edit_notices($coupon_id, $notices_status_id, $time_next_scheduled, $notices_coupon_cron, $coupon_emails, $coupon_code);

            $a1 = __( 'YES', 'giveaways-for-woocommerce');
            $a2 = __( 'NO', 'giveaways-for-woocommerce');

            DCP_ADMIN_NOTICES::add_custom_notice(
    			'sse_coupon_' . (int) $user_id . '_' . (int) $coupon_id,
    			 $p1 . '<p class="submit">'
    				. '<button class="button-primary sse_ok_notices_dispatch" data-id-coupon="' . (int) $coupon_id
    					. '" data-user-id="' . (int) $user_id . '">' . $a1 . '</button>'
    				. ' <button class="button-secondary sse_no_notices_dispatch" data-id-coupon="' . (int) $coupon_id
    					. '" data-user-id="' . (int) $user_id . '">' . $a2 . '</button>'
    				. '</p>'
            );
        }

    }

     /**
	 * Message for adding notifications.
	 *
	 * @param integer $id
	 * @param integer $status_id
	 * @param bool $cron
	 * @param string $list
	 * @param string $coupon_code
	 * @return string
	 */
    private function add_notices($id, $status_id, $cron, $list, $coupon_code) {
        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;
        $user_login = $current_user->user_login;
        $user_roles = $current_user->roles;
        $user_roles_str = implode(',', $user_roles);

        $head = '<h3 class = "sse_h_notices_dispatch">Message from the plugin "Giveaways for woocommerce" the user %1$s(%2$s)</h3>';
    if($status_id == 2){
            if ($cron) {
                if (empty($list)) {
                    $content = __(
                        'Confirm CRON task for sending notifications to all store customers about the coupon <strong>"%3$s"</strong>.',
                        'giveaways-for-woocommerce');
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code);
                } else {
                    $content = __(
                        'Confirm the CRON task to send notification to specified users about the coupon <strong>"%3$s"</strong>.',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code);
                }
            } else {
                if (empty($list)) {
                    $content = __(
                        'Confirm to send notification to all store customers about the coupon <strong>"%3$s"</strong>.',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                } else {
                    $content = __(
                        'Confirm to send notification to specified users about the coupon <strong>"%3$s"</strong>.',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                }
            }
    }

    if($status_id == 7){
            if ($cron) {
                if (empty($list)) {
                    $content = __(
                        'Confirm CRON task to send a notification to all store customers about the coupon <strong>"%3$s"</strong> (complete cleaning).',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                } else {
                    $content = __(
                        'Confirm the CRON task to send notification to specified users about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                }
            } else {
                if (empty($list)) {
                    $content = __(
                        'Confirm sending notifications to all customers of the store about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                        'giveaways-for-woocommerce' );
                    $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                } else {
                    $content = __(
                        'Confirm sending notifications to the specified users about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                        'giveaways-for-woocommerce' );
                    $message = sprintf(  $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                }
            }
    }

    	return $message;

    }

     /**
	 * Message to delete notifications.
	 *
	 * @param integer $id
	 * @param integer $status_id
	 * @param string $coupon_code
	 * @return string
	 */
    private function remove_notices($id, $status_id, $coupon_code) {
        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;
        $user_login = $current_user->user_login;
        $user_roles = $current_user->roles;
        $user_roles_str = implode(',', $user_roles);

     $head = '<h3 class = "sse_h_notices_dispatch">Message from the plugin "Giveaways for woocommerce" the user %1$s(%2$s)</h3>';

    if($status_id == 4){
        $content = __( 'Confirm deletion notifications about coupon  (CRON tasks) <strong>"%3$s"</strong>.',
    		'giveaways-for-woocommerce' );
        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>', $user_login, $user_roles_str, $coupon_code );
    }

    if($status_id == 6){
        $content = __( 'Confirm deletion notifications about coupon  (CRON tasks) <strong>"%3$s"</strong>(complete cleaning).',
            'giveaways-for-woocommerce' );
        $message = sprintf(  $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>', $user_login, $user_roles_str, $coupon_code );
    }


    	return $message;
    }

    /**
	 * Message for changing notifications.
	 *
	 * @param integer $id
	 * @param integer $status_id
	 * @param integer | false $time
	 * @param bool $cron
	 * @param string $list
	 * @param string $coupon_code
	 * @return string
	 */
    private function edit_notices($id, $status_id, $time, $cron, $list, $coupon_code) {
        $current_user = wp_get_current_user();
        $user_id = $current_user->ID;
        $user_login = $current_user->user_login;
        $user_roles = $current_user->roles;
        $user_roles_str = implode(',', $user_roles);

        $head = '<h3 class = "sse_h_notices_dispatch">Message from the plugin "Giveaways for woocommerce" the user %1$s(%2$s)</h3>';

    if($status_id == 3){
    	 if ($time > 0) {
                if ($cron) {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the update for the task CRON to send notifications to all customers of the store about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the update for the task CRON to send notifications to the specified users of the store about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                } else {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the sending of notifications and the cancellation of the CRON task to all store customers about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the sending of notifications and the cancellation of the CRON task to specified users about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                }
            } else {
                if ($cron) {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the removal of notifications and the addition of the CRON task to all store customers about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the removal of notifications and the addition of the CRON task to specified users about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                } else {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the update of notifications to all customers of the store about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the update of notifications to specified users about the coupon <strong>"%3$s"</strong>.',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                }
            }
    }

    if($status_id == 5){
    	 if ($time > 0) {
                if ($cron) {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the CRON task update for the send notification to all store customers about  the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the CRON task update for the send notification to the specified users about  the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                } else {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the sending of notifications and the cancellation of the CRON task to all store customers about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the sending of notifications and the cancellation of the CRON task to specified users about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                }
            } else {
                if ($cron) {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the removal of notifications and the addition of the CRON task to all store customers about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the removal of notifications and adding a CRON task to specified users about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                } else {
                    if (empty($list)) {
                        $content = __(
                            'Confirm the update of notifications to all customers of the store about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    } else {
                        $content = __(
                            'Confirm the update of notifications to specified users about the coupon <strong>"%3$s"</strong>(complete cleaning).',
                            'giveaways-for-woocommerce' );
                        $message = sprintf( $head . '<p class = "sse_p_notices_dispatch">' . $content . '</p>' , $user_login, $user_roles_str, $coupon_code );
                    }
                }
            }
    }
    	return $message;
    }

    /**
     * An error message is generated for the administrator.
     *
     * @param string $err_status
     * @param string $messag_err
     * @param integer $user_id
     * @param integer $coupon_id
     */
    public function confirm_sending_emails_err($err_status, $messag_err, $user_id, $coupon_id) {
        $a2 = __("Close", 'giveaways-for-woocommerce');

        DCP_ADMIN_NOTICES::add_custom_notice(
			'coupon_err_' . $err_status . '_' . (int) $user_id . '_' . (int) $coupon_id,
			 $messag_err . ' <button class="button-secondary sse_no_notices_err" data-id-coupon="'. (int) $coupon_id
			. '" data-user-id="' . (int) $user_id
			. '" data-err-status="'. $err_status . '">' . $a2 . '</button>'
			);
    }


    /**
     * Map one of the DCP_COUPON error codes to a message string.
     *
     * @param int $err_code Message/error code.
     * @return string| Message/error string
     */
    public function get_coupon_error($err_code) {
        switch ($err_code) {
            case self::E_WC_COUPON_INVALID_FILTERED:
                $err = __('Coupon is not valid.', 'giveaways-for-woocommerce');
                break;
            case self::E_WC_COUPON_EXPIRED:
                $err = __('This coupon has expired.', 'giveaways-for-woocommerce');
                break;
            default:
                $err = '';
                break;
        }

        return apply_filters('dcp_cp_ntc_error_sse', $err, $err_code, $this);
    }

}